/* eslint-disable @typescript-eslint/no-duplicate-enum-values */
// ======================================================================
// ======================================================================
//
//   GNU GENERAL PUBLIC LICENSE
//   Version 3, 29 June 2007
//   copyright (C) 2020 - 2021 Quentin Gruber
//   copyright (C) 2021 - 2024 H1emu community
//
//   https://github.com/QuentinGruber/h1z1-server
//   https://www.npmjs.com/package/h1z1-server
//
//   Based on https://github.com/psemu/soe-network
// ======================================================================

export enum PositionUpdateType {
  STATIC = 0,
  MOVABLE = 1
  // there are others we can get by looking at the vehicle packets
}

export enum ItemUseOptions {
  EAT = 1,
  DRINK = 2,
  USE = 3,
  DROP = 4,
  SHRED = 6,
  UNLOAD = 7,
  UNPACK = 10,
  IGNITE = 11,
  REPAIR = 16,
  REFUEL = 17,
  SLICE = 18,
  UNPACK_BUNDLE = 20,
  APPLY_SKIN = 24,
  CALL_AIRDROP = 25,
  OPEN_BAG = 26,
  OPEN_PACKAGE = 46,
  USE_MEDICAL = 52,
  USE_AIRDROP = 58,
  LOOT = 59,
  EQUIP = 60,
  MOVE = 61,
  HOTWIRE_ATV = 62,
  LOOT_VEHICLE_LOADOUT = 66,
  MOVE_VEHICLE_PARTS = 67,
  HOTWIRE_OFFROADER = 70,
  HOTWIRE_PICKUP = 71,
  HOTWIRE_POLICE = 72,
  DROP_BATTERY = 73,
  LOOT_BATTERY = 75,
  MOVE_BATTERY = 76,
  DROP_SPARKS = 79,
  LOOT_SPARKS = 81,
  MOVE_SPARKS = 82,
  OPEN_CRATE = 85,
  SALVAGE = 87,
  HOTWIRE_ATV_NO_PARTS = 90,
  HOTWIRE_OFFROADER_NO_PARTS = 91,
  HOTWIRE_PICKUP_NO_PARTS = 92,
  HOTWIRE_POLICE_NO_PARTS = 93
}

export enum ConstructionErrors {
  UNKNOWN = "Unknown",
  OVERLAP = "Construction overlap",
  BUILD_PERMISSION = "No build permission",
  DEMOLISH_PERMISSION = "No demolish permission",
  UNKNOWN_PARENT = "Unknown parent",
  UNKNOWN_SLOT = "Unknown slot",
  UNKNOWN_CONSTRUCTION = "Unknown construction item",
  OUT_OF_RANGE = "Out of range",
  STACKED = "Construction stacked",
  TREESTACKED = "Construction tree stacked"
}

export enum ConstructionPermissionIds {
  BUILD = 1,
  DEMOLISH = 2,
  CONTAINERS = 3,
  VISIT = 4
}

export enum ModelIds {
  LOOT_BAG_LARGE = 9581,
  MILITARY_CRATE = 9218,
  MILITARY_CRATE_PARACHUTE = 9219,
  BURLAP_BAG_LARGE = 9391,
  HOSPITAL_LAB_WORKBENCH = 9563,
  HOSPITAL_DESK = 9551,
  HOSPITAL_LAB_COUNTERTOP = 9553,
  HOSPITAL_GROSSING_STATION = 9556,
  HOSPITAL_REFRIGERATOR = 9555,
  HOSPITAL_SINK_COUNTERTOP = 9554,
  HOSPITAL_DRUG_CABNINET = 9552,
  TREASURE_CHEST = 9347,
  METAL_STORAGE_CHEST = 57,
  CRATE_LONG = 8014,
  CRATE_BOX_1 = 8013,
  CRATE_BOX_2 = 9088,
  BARELL_1 = 9387,
  GLASS_WINDOW_01 = 8026,
  TINTED_WINDOW_01 = 9432,
  GLASS_WINDOW_DESTROYED_1 = 8027,
  GLASS_WINDOW_DESTROYED_2 = 8028,
  GLASS_WINDOW_DESTROYED_3 = 8029,
  TINTED_WINDOW_DESTROYED_1 = 9433,
  TINTED_WINDOW_DESTROYED_2 = 9434,
  TINTED_WINDOW_DESTROYED_3 = 9435,
  GARBAGE_CAN_01 = 9007,
  ARMOIRE_01 = 9006,
  ARMOIRE_02 = 9124,
  DRESSER_01 = 9005,
  DRESSER_02 = 9125,
  OTTOMAN_01 = 9149,
  OTTOMAN_02 = 9150,
  TOOL_CABINET_01 = 9074,
  TOOL_CABINET_02 = 9035,
  BLUE_TOOL_CABINET = 9500,
  RED_SILVER_TOOL_CABINET = 9501,
  CABINETS_BATHROOM_01 = 9031,
  CABINETS_BATHROOM_02 = 9237,
  CABINETS_BATHROOM_SINK = 9032,
  CABINET_SET_01 = 9352,
  CABINET_SET_02 = 9353,
  CABINET_SET_03 = 9362,
  CABINET_SET_04 = 9363,
  CABINET_SET_05 = 9364,
  CABINET_SET_06 = 9365,
  CABINET_SET_07 = 9366,
  CABINET_SET_08 = 9367,
  CABINET_SET_09 = 9368,
  CABINET_SET_10 = 9369,
  CABINET_SET_11 = 9370,
  CABINETS_KITCHEN_01 = 9011,
  CABINETS_KITCHEN_02 = 9012,
  CABINETS_KITCHEN_03 = 9026,
  CABINETS_KITCHEN_04 = 9027,
  CABINETS_KITCHEN_05 = 9028,
  CABINETS_KITCHEN_06 = 9239,
  OFFICE_CUBE_CABINET = 9229,
  OFFICE_CABINETS_01 = 9226,
  OFFICE_CABINETS_02 = 9227,
  OFFICE_CABINETS_03 = 9228,
  PLYWOOD_METAL_GATE = 49,
  RESIDENTIAL_DOOR_1 = 9009,
  RESIDENTIAL_DOOR_2 = 9165,
  RESIDENTIAL_DOOR_3 = 9167,
  RESIDENTIAL_DOOR_4 = 9169,
  RESIDENTIAL_DOOR_5 = 9171,
  RESIDENTIAL_FRONT_DOOR_1 = 9497,
  RESIDENTIAL_FRONT_DOOR_2 = 9904,
  RESIDENTIAL_INTERIOR_DOOR = 9905,
  CAMPER_DOOR_1 = 9333,
  CAMPER_DOOR_GLASS_BROKEN_1 = 9334,
  CAMPER_DOOR_GLASS_BROKEN_2 = 9335,
  CHURCH_DOOR = 9136,
  OFFICE_DOOR = 9224,
  MENS_LEFT_DOOR = 9232,
  WOMENS_LEFT_DOOR = 9233,
  FREEZER_DOOR = 9243,
  INDUSTRIAL_DOOR_1 = 9903,
  INDUSTRIAL_DOOR_2 = 9246,
  PUSH_DOOR = 9498,
  RESTAURANT_DOOR_GLASS_BROKEN_1 = 9452,
  RESTAURANT_DOOR_GLASS_BROKEN_2 = 9453,
  RESTAURANT_DOOR_GLASS_BROKEN_3 = 9454,
  RESTAURANT_DOOR_1 = 9455,
  BUISNESS_DOOR_GLASS = 9183,
  BUISNESS_DOOR_GLASS_BROKEN_1 = 9184,
  BUISNESS_DOOR_GLASS_BROKEN_2 = 9185,
  BUISNESS_DOOR_GLASS_BROKEN_3 = 9186,
  CABIN_DOOR = 9901,
  CABIN_DOOR_BROKEN = 9902,
  BUISNESS_DOORS_GLASS = 9897,
  BUISNESS_DOORS_GLASS_BROKEN_1 = 9898,
  BUISNESS_DOORS_GLASS_BROKEN_2 = 9899,
  BUISNESS_DOORS_GLASS_BROKEN_3 = 9900,
  DESK = 9038,
  LOCKERS_LOCKER_POLICE = 9254,
  LOCKERS_LOCKER_WEAPONS = 9255,
  OFFROADER = 7225,
  PICKUP_TRUCK = 9258,
  POLICE_CAR = 9301,
  ATV = 9588,
  PARACHUTE = 9374,
  SPECTATE = 9371,
  PICKUP_DESTROYED = 9315,
  POLICE_CAR_DESTROYED = 9316,
  ATV_DESTROYED = 9593,
  OFFROADER_DESTROYED = 7226,
  WRECKED_TRUCK_01 = 9108,
  WRECKED_TRUCK_OD_01 = 9178,
  WRECKED_CAR_OD_01 = 9179,
  WRECKED_CAR = 9105,
  WRECKED_VAN = 9110,
  AIRDROP_CARGO_CONTAINER = 9384,
  AIRDROP_PLANE = 9215,
  OFFICE_FILING_CABINET = 9225,
  LAB_GLASS_CABINET = 9256,
  KITCHEN_FRIDGE = 9030,
  FILE_CABINETS = 9034,
  DUMPSTER = 9037,
  WASHER = 9396,
  DRYER = 9395,
  CAMPFIRE = 9041,
  BARBEQUE = 9205,
  FURNACE = 36,
  HAND_SHOVEL = 9248,
  ZOMBIE_SCREAMER = 9667,
  ZOMBIE_FEMALE_WALKER = 9510,
  ZOMBIE_MALE_WALKER = 9634,
  DEER_BUCK = 9253,
  DEER = 9002,
  WOLF = 9003,
  BEAR = 9187,
  RAVEN = 9230,
  CORN_CROPSTATE_1 = 59,
  CORN_CROPSTATE_2 = 60,
  CORN_CROPSTATE_3 = 61,
  WHEAT_CROPSTATE_1 = 9191,
  WEHAT_CROPSTATE_2 = 9190,
  WHEAT_CROPSTATE_3 = 9189,
  BARBED_WIRE = 28,
  BARBED_WIRE_POSTS = 43,
  SNARE = 1974,
  BATTERY = 70,
  FIRE_HYDRANT = 9337,
  SURVIVOR_MALE_HEAD_01 = 9240,
  SURVIVAL_FEMALE_HEAD_01 = 9474,
  ZOMBIE_FEMALE_HEAD = 9510,
  ZOMBIE_MALE_HEAD = 9634,
  GROUND_TAMPER = 9115,
  DECK_EXPANSION = 9492,
  METAL_SHACK_DOOR = 9181,
  METAL_SHACK = 9180,
  SMALL_SHACK = 9192,
  DEW_COLLECTOR = 55,
  WOOD_SHACK = 9223,
  WOOD_SHACK_DOOR = 63,
  RAMP = 9487,
  FOUNDATION_STAIRS = 9488,
  METAL_GATE = 49,
  METAL_WALL = 50,
  UPPER_METAL_WALL = 9407,
  SHELTER = 51,
  LARGE_SHELTER = 52,
  UPPER_LEVEL_SHELTER = 9408,
  UPPER_LEVEL_LARGE_SHELTER = 9411,
  STRUCTURE_STAIRS = 53,
  TOWER = 9493,
  DECK_FOUNDATION = 9130,
  FENCES_WOOD_PLANKS_GREY_POSTS_1X2 = 8037,
  FENCES_WOOD_PLANKS_GREY_POSTS_1X1 = 8036,
  FENCES_WOOD_PLANKS_GREY_1X1 = 8033,
  FENCES_WOOD_PLANKS_GREY_PLANK = 8035,
  FENCES_WOOD_PLANKS_GREY_GAP_1X1 = 8034,
  BARBED_WIRE_FENCE_1X2 = 9114,
  BARBED_WIRE_FENCE_1X1 = 9113,
  FENCE_RANCH_1X2 = 9403,
  FENCE_RANCH_1X1 = 9402,
  CHAIN_LINK_FENCE_1X1 = 8024,
  CHAIN_LINK_FENCE_1X2 = 8025,
  SIGNS_STOP_SIGN_01 = 8021,
  SIGNS_STOP_SIGN_01_DESTROYED = 8022,
  TRAFFIC_SIGNS_STOP_SIGN = 9927,
  TRAFFIC_SIGN_POLE = 9942,
  TRAFFIC_SIGN_POLE_DOUBLE = 9947,
  TRAFFIC_SIGNS_HIGHWAY_LARGE_SIGNS_ROAD_TWO_POST_01 = 9948,
  TRAFFIC_SIGN_HIGHWAY_WOOD_BASE = 9981,
  TRAFFIC_SIGNS_HIGHWAY_LARGE_SIGNS_WOOD_TWO_POST_01 = 9982,
  TRAFFIC_SIGNS_HIGHWAY = 9992,
  TRAFFIC_SIGNS_TOWN = 9918,
  STREET_SIGNS_STREET_NAMES_SIGN_POST = 9950,
  STREET_SIGNS_STREET_NAMES_SIGN = 9943,
  STREET_SIGN_POLE = 9944
}

export enum StringIds {
  ENTER_VEHICLE = 15,
  OFFROADER = 16,
  WATER_WELL = 1006,
  COLLECT_WATER = 1008,
  DRINK_DIRTY_WATER = 1331,
  DRINK_STAGNANT_WATER = 1461,
  DIRTY_WATER = 1099,
  TAKE_ITEM = 29,
  OPEN = 31,
  CORN = 628,
  WHEAT = 1184,
  USE_TARGET = 1186,
  SEARCH = 1191,
  SEARCH_ALL_CABINETS = 9242,
  OPEN_AND_LOCK = 8944,
  REST = 9041,
  RESTING = 9051,
  NOT_TIRED = 12159,
  USE_IGNITABLE = 9224,
  USE_DOOR = 78,
  UNDO_PLACEMENT = 12001,
  OPEN_TARGET = 12156,
  ATV = 12552,
  PICKUP_TRUCK = 12537,
  POLICE_CAR = 12538,
  PERMISSIONS_TARGET = 12982,
  EXTRACT_BLOOD = 1453,
  HARVEST = 1009,
  LONG_RANGE_RADIO = 12809,
  RADIOLOGY_DESK = 12752,
  BATTERED_TRASHCAN = 12835,
  MAINTENANCE_TOOLBOX = 12736,
  ICU_DESK = 12750,
  OPEN_TOOLBOX = 12739,
  OPEN_CABINET = 12732,
  SMALL_PHARMACY_CABINET = 12740,
  SEARCH_RECORDS = 12735,
  RECORDS_CABINET = 12734,
  EXAMINATION_CABINET = 12719,
  MORGUE_DESK = 12696,
  LOCKED_CABINET = 12744,
  OPEN_LOCKED_CABINET = 12747,
  AIRDROP_CODE = 12795,
  ZOMBIE_WALKER = 60,
  DEER = 1245,
  BEAR = 1246,
  WOLF = 1213,
  CHECK_WATER = 9833,
  FIRE_HYDRANT = 14383,
  TACTICAL_ARMOR = 12073,
  WOODEN_ARMOR = 11151,
  PLATED_ARMOR = 11153,
  TACTICAL_HELMET = 9945,
  SLEIGH_HELMET = 12994,
  GENERAL_HELMET_1 = 9114,
  CREEPY_MASK = 12898,
  SCRAY_HALLOWEEN_MASK = 12858,
  UNCLE_SAM_MASK = 14171,
  CONVEYS = 11895,
  BANSHEE = 12310
}

export enum MovementModifiers {
  RESTED = 1.11,
  SWIZZLE = 1.1,
  SNARED = 0.5,
  CONVEYS = 1.15,
  BOOTS = 1.07
}

export enum ContainerErrors {
  NONE = 0,
  IN_USE = 1,
  WRONG_ITEM_TYPE = 2,
  UNKNOWN_CONTAINER = 3,
  UNKNOWN_SLOT = 4,
  NO_ITEM_IN_SLOT = 5,
  INTERACTION_VALIDATION = 6,
  UNKNOWN = 99,

  // custom errors
  DOES_NOT_ACCEPT_ITEMS = 7,
  NOT_MUTABLE = 8,
  NOT_CONSTRUCTED = 9,
  NO_SPACE = 10,
  INVALID_LOADOUT_SLOT = 11,
  NO_PERMISSION = 12,
  UNACCEPTED_ITEM = 13
}

export enum FilterIds {
  COOKING = 2,
  FURNACE = 4,
  WEAPONS = 5,
  HOUSING = 6,
  SURVIVAL = 7,
  COMPONENT = 8,
  DEW_COLLECTOR = 9,
  ANIMAL_TRAP = 10
}

export enum ItemClasses {
  WEAPONS_LONG = 25036,
  WEAPONS_PISTOL = 4096,
  WEAPONS_MELEES = 4098,
  WEAPONS_MELEES0 = 25037,
  WEAPONS_GENERIC = 25054,
  WEAPONS_CROSSBOW = 25047,
  WEAPON_THROWABLES = 25078,
  WEAPONS_BOW = 25038,
  POUCHES = 25013,
  BACKPACKS = 25004,
  THROWABLES = 25078
}

export enum VehicleIds {
  OFFROADER = 1,
  PICKUP = 2,
  POLICECAR = 3,
  ATV = 5,
  PARACHUTE = 13,
  SPECTATE = 1337
}

export enum NpcIds {
  ZOMBIE = 3,
  DEER = 13,
  WOLF = 14,
  BEAR = 825,
  RABBIT = 864,
  RAVEN = 893
}

export enum Characters {
  MALE_WHITE = 1,
  MALE_WHITE_BALD = 2,
  FEMALE_WHITE_YOUNG = 3,
  FEMALE_WHITE = 4,
  MALE_BLACK = 5,
  FEMALE_BLACK = 6
}

export enum LoadoutIds {
  CHARACTER = 3,
  VEHICLE_OFFROADER = 4,
  VEHICLE_PICKUP = 6,
  VEHICLE_POLICECAR = 8,
  VEHICLE_ATV = 14
}

export enum LoadoutSlots {
  PRIMARY = 1,
  SECONDARY = 3,
  TERTIARY = 4,
  FISTS = 7,
  CHEST = 10,
  HEAD = 11,
  BACK = 12,
  LEGS = 14,
  BELT = 25,
  EYES = 29,
  EXTERNAL_CONTAINER = 31,
  VEHICLE_BATTERY = 33,
  ARMOR = 38,
  RADIO = 39,
  ITEM1 = 40,
  ITEM2 = 41
}

export enum EquipSlots {
  HEAD = 1,
  HANDS = 2,
  CHEST = 3,
  LEGS = 4,
  FEET = 5,
  RHAND = 7,
  BACKPACK = 10,
  HAIR = 27,
  FACE = 28,
  EYES = 29,
  ARMOR = 100
}

export enum ResourceIds {
  HEALTH = 1,
  HUNGER = 4,
  HYDRATION = 5,
  STAMINA = 6,
  VIRUS = 12,
  BLEEDING = 21,
  ENDURANCE = 22,
  COMFORT = 68,
  FUEL = 396,
  CONDITION = 561,
  CONSTRUCTION_CONDITION = 567
}

export enum ResourceTypes {
  HEALTH = 1,
  HUNGER = 4,
  HYDRATION = 5,
  STAMINA = 6,
  VIRUS = 12,
  BLEEDING = 21,
  ENDURANCE = 22,
  COMFORT = 68,
  FUEL = 50,
  CONDITION = 1
}

export enum ResourceIndicators {
  BLEEDING_LIGHT = "BLEEDING_LIGHT",
  BLEEDING_MODERATE = "BLEEDING_MODERATE",
  BLEEDING_SEVERE = "BLEEDING_SEVERE",
  TIRED = "TIRED",
  VERY_TIRED = "VERY_TIRED",
  EXHAUSTED = "EXHAUSTED",
  WELL_RESTED = "WELL_RESTED",
  HEALING_BANDAGE = "HEALING_BANDAGE",
  HEALING_BANDAGE_DRESSED = "HEALING_BANDAGE_DRESSED",
  HEALING_FIRST_AID = "HEALING_FIRST_AID",
  IMMUNITY_BOOST_LOW = "IMMUNITY_BOOST_LOW",
  IMMUNITY_BOOST_MEDIUM = "IMMUNITY_BOOST_MEDIUM",
  COLD_MEDICINE = "COLD_MEDICINE",
  SWIZZLE = "SWIZZLE",
  DEHYDRATED = "DEHYDRATED",
  STARVING = "STARVING",
  COMFORT_PLUS = "COMFORT +",
  COMFORT_PLUSPLUS = "COMFORT ++",
  FOOD_POISONING = "FOOD POISONING",
  BEES = "BEES!"
}

export enum Abilities {
  VEHICLE_HEADLIGHTS = 99998,
  VEHICLE_TURBO = 1111141,
  VEHICLE_SIREN = 1111295,
  VEHICLE_HORN = 1111301
}

export enum TreeIds {
  COMMONHAZEL = 0,
  WESTERNCEDARSAPLING = 1,
  WESTERNCEDAR = 2,
  GREENMAPLEDEAD = 3,
  SAPLINGMAPLE = 4,
  REDMAPLE = 5,
  GREENMAPLE = 6,
  BOULDERS = 7,
  WHITEBIRCH = 8,
  DEVILCLUB = 9,
  REDCEDAR = 10,
  VINEMAPLE = 11,
  OREGONOAK = 12,
  BLACKBERRY = 13,
  PAPERBIRCH = 14,
  BIGLEAFMAPLE = 15,
  BIGLEAFMAPLE_YOUNG01 = 16,
  BIGLEAFMAPLE_YOUNG02 = 17,
  DECIDUOUSSHRUB01 = 18,
  BOULDER = 19,
  APPLETREE01 = 20,
  BUSHES_LARGE01 = 21
}

/* I got these values from Z1BR - Jason */
export enum Recipes {
  GUNPOWDER = 2,
  METAL_SHEET = 6,
  PIPE = 7,
  COMBAT_KNIFE = 8,
  SLEEPING_MAT = 18,
  COFFEE = 22,
  TORCH = 23,
  MAKESHIFT_HATCHET = 24,
  FLARE = 25,
  DEER_STEAK = 28,
  FURNACE = 31,
  COFFEE_SUGAR = 39,
  FUEL = 40,
  LANDMINE = 41,
  SALINE = 42,
  FIRST_AID = 43,
  MACHETTE = 46,
  DEER_JERKY = 47,
  STORAGE = 48,
  ANIMAL_TRAP = 51,
  DEW_COLLECTOR = 54,
  PUNJI_STICKS = 55,
  METAL_SHARD = 61,
  BARBED_WIRE = 65,
  COOKED_RABBIT = 66,
  RABBIT_STEW = 67,
  WOLF_STEAK = 68,
  WOODEN_BARRICADE = 69,
  NAIL = 71,
  METAL_BRACKET = 72,
  FRAMED_BACKPACK = 76,
  METAL_GATE = 78,
  METAL_WALL = 79,
  SHELTER = 80,
  LARGE_SHELTER = 81,
  STRUCTURE_STAIRS = 82,
  BLACKBERRY_JUICE = 103,
  GRILLED_TROUT = 104,
  PURIFIED_WATER_1 = 107, // From dirty water
  DECK_FOUNDATION = 109,
  SURVIVAL_BORSCHT = 110,
  GROUND_TILLER = 112,
  ETHANOL = 113,
  CORN_MASH = 114,
  ROASTED_CORN = 115,
  MOLOTOV_COCKTAIL = 116,
  ETHANOL_TORCH = 117,
  SATCHEL = 118,
  SNARE = 119,
  SHACK = 120,
  WOODEN_DOOR = 121,
  SMALL_SHACK = 122,
  IMPROVISED_COMPASS = 124,
  YEAST = 125,
  BARBEQUE = 126,
  BEAR_STEAK = 128,
  BOW_DRILL = 129,
  FLOUR = 131,
  SURVIVAL_BREAD = 132,
  DEER_SANDWICH = 133,
  BEAR_SANDWICH = 134,
  WOLF_SANDWICH = 135,
  RABBIT_SANDWICH = 136,
  DEER_SCENT = 137,
  BACKPACK_FRAME = 138,
  BASIC_SHACK = 139,
  BASIC_SHACK_DOOR = 140,
  PURIFIED_WATER_2 = 141, // From stagnant water
  HAMMER = 142,
  SMOKE_FLARE = 144,
  HAND_SHOVEL = 145,
  IED = 146,
  GROUND_TAMPER = 147,
  BLACKBERRY_PIE = 148,
  SWIZZLE = 149,
  RIGGED_LIGHT = 154,
  METAL_DOOR = 166,
  GUN_REPAIR_KIT = 171,
  WORKBENCH = 172,
  UPPER_METAL_WALL = 173,
  UPPER_LEVEL_LARGE_SHELTER = 174,
  UPPER_LEVEL_SHELTER = 175,
  UPPER_LEVEL_STAIRS = 176,
  DEMOLITION_HAMMER = 177,
  GUN_PART_1 = 193, // From M1911A1
  GUN_PART_2 = 194, // From AR-15
  GUN_PART_3 = 195, // From 308
  GUN_PART_4 = 195, // From Magnum
  GUN_PART_5 = 197, // From Crafted Shotgun
  GUN_PART_6 = 198, // From R380
  GUN_PART_7 = 199, // From M9
  GUN_PART_8 = 200, // From Riot Shotgun
  CANDLE = 202,
  BEE_BOX = 203,
  WOODEN_BODY_ARMOR = 204,
  PLATED_BODY_ARMOR = 205,
  DRESSED_BANDAGE = 206,
  METAL_DOORWAY = 207,
  SANDBAG_WALL = 208,
  FOUNDATION_RAMP = 214,
  FOUNDATION_STAIRS = 215,
  GUN_PART_9 = 216, // From AK-47
  LOOKOUT_TOWER = 217,
  FOUNDATION_EXPANSION = 218,
  FLAMING_ARROW_1 = 220, // From Scrap of Cloth(23), Fuel(73) and Wooden Arrow(112)
  PARACHUTE_FLARE = 221,
  BASIC_BANDANA = 222,
  FINGERLESS_GLOVES = 223,
  MODIFIED_AK47 = 224,
  GUN_UPGRADE_KIT = 230,
  MODIFIED_TOXIC_AK47 = 231,
  MEDICATED_BANDAGE = 232,
  SYRINGE_H1Z1_REDUCER = 233,
  SYRINGE_H1Z1_SUPPRESSANT = 234,
  SYRINGE_H1Z1_INFECTED_BLOOD = 235,
  SUPPRESSANT_MIXTURE_K49 = 236,
  VIAL_H1Z1_SUPPRESSANT = 237,
  ANTIBIOTIC_CREAM = 239,
  IDENTIFIED_ANTI_VIRAL_BOTTLE = 240,
  CHARGED_PHONE = 241,
  TREATED_BRAIN = 242,
  AIRDROP_CODE = 248,
  TAN_GHILLIE_SUIT = 249,
  HUGZ_NEEDED_SCRUBS_SHIRT = 250,
  KURUMA_MEDICAL_SCRUBS_SHIRT = 251,
  MILITARY_SCRUBS_SHIRT = 252,
  HAPPY_SKULL_SCRUBS_SHIRT = 253,
  FIRE_TRAP = 258,
  TRAP_IGNITION_KIT = 259,
  FLASH_TRAP = 260,
  GAS_TRAP = 261,
  SHOCK_TRAP = 262,
  REPAIR_BOX = 288,
  SCREAM_GRENADE = 289,
  HANDFUL_BLACKBERRIES = 290,
  FLAMING_ARROW_2 = 291, // From Molotov Cocktail(14), Wooden Arrow(112), Duct Tape (134) and 12 Gauge Buckshot Shell(1511)
  MAKESHIFT_ARMOR = 293,
  EXPLOSIVE_ARROW = 294,
  PROCOAGULANT = 297,
  PURGE = 304,
  FROSTBITE = 305,
  REAPER = 306,
  BLAZE = 307,
  NAGAFENS_RAGE = 308,
  BLUE_CRESCENDO = 309,
  JAGGED_SKINNING_KNIFE = 310,
  PUNJI_STICK_ROW = 312,
  FIELD_BANDAGE = 325
}

export enum Items {
  //#region WEAPONS
  WEAPON_AR15 = 10,
  WEAPON_AK47 = 2229,
  WEAPON_SHOTGUN = 1374,
  WEAPON_CROWBAR = 82,
  WEAPON_COMBATKNIFE = 84,
  WEAPON_MACHETE01 = 83,
  WEAPON_KATANA = 2961,
  WEAPON_BAT_WOOD = 1724,
  WEAPON_GUITAR = 1733,
  WEAPON_AXE_WOOD = 58,
  WEAPON_AXE_FIRE = 1745,
  WEAPON_HAMMER = 1536,
  WEAPON_HATCHET = 3,
  WEAPON_PIPE = 1448,
  WEAPON_BAT_ALUM = 1721,
  WEAPON_BOW_MAKESHIFT = 113,
  WEAPON_BOW_WOOD = 1720,
  WEAPON_BOW_RECURVE = 1986,
  WEAPON_1911 = 2,
  WEAPON_M9 = 1997,
  WEAPON_308 = 1373,
  WEAPON_BINOCULARS = 1542,
  WEAPON_CROSSBOW = 2246,
  WEAPON_R380 = 1991,
  WEAPON_MOLOTOV = 14,
  WEAPON_MAGNUM = 1718,
  WEAPON_FLASHLIGHT = 1380,
  WEAPON_WRENCH = 1538,
  WEAPON_BRANCH = 1725,
  WEAPON_FISTS = 85,
  WEAPON_FROSTBITE = 3445,
  WEAPON_BLAZE = 3446,
  WEAPON_NAGAFENS_RAGE = 3448,
  WEAPON_PURGE = 3449,
  WEAPON_REAPER = 3450,
  WEAPON_HAMMER_DEMOLITION = 1903,
  WEAPON_TORCH = 5,
  WEAPON_TORCH_ETHANOL = 1389,
  WEAPON_HATCHET_MAKESHIFT = 1708,
  WEAPON_AK47_MODIFIED = 2399,
  WEAPON_SPEAR = 1382,
  WEAPON_REMOVER = 1776,
  //#endregion

  //#region AMMO
  AMMO_223 = 1429,
  AMMO_12GA = 1511,
  AMMO_45 = 1428,
  AMMO_9MM = 1998, // TODO = assign it to a spawner
  AMMO_308 = 1469,
  AMMO_380 = 1992,
  AMMO_762 = 2325,
  AMMO_44 = 1719,
  AMMO_ARROW = 112,
  AMMO_ARROW_EXPLOSIVE = 138,
  AMMO_ARROW_FLAMING = 1434,
  //#endregion

  //#region AMMO_BOX
  AMMO_BOX_223 = 1430,
  AMMO_BOX_45 = 8,
  //#endregion

  //#region PERISHABLE
  ANTIBIOTICS = 1388,
  PAINKILLERS = 2509,
  ADRENALINE_SHOT = 2512,
  VITAMINS = 1512,
  IMMUNITY_BOOSTERS = 1471,
  FIRST_AID = 78,
  BANDAGE = 24,
  BANDAGE_DRESSED = 2214,
  BUNDLE_GAUZE = 1750,
  BUNDLE_WOODEN_ARROWS = 1782,
  BUNDLE_WOODEN_ARROWS_1 = 1892,
  BUNDLE_EXPLOSIVE_ARROWS = 2400,
  BUNDLE_FLAMING_ARROWS = 2401,
  BUNDLE_WOODEN_ARROWS_2 = 3379,
  GAUZE = 1751,
  SWIZZLE = 1709,
  GROUND_COFFEE = 56, // TODO = expand with more canned food types
  CANNED_FOOD01 = 7,
  CANNED_FOOD02 = 1393,
  CANNED_FOOD03 = 1394,
  CANNED_FOOD04 = 1391,
  CANNED_FOOD05 = 1392,
  CANNED_FOOD06 = 1396,
  CANNED_FOOD07 = 1397,
  CANNED_FOOD08 = 1398,
  CANNED_FOOD09 = 1399,
  CANNED_FOOD10 = 1400,
  CANNED_FOOD11 = 1401,
  CANNED_FOOD25 = 1431,
  CANNED_FOOD21 = 1395,
  CANNED_FOOD26 = 2536,
  BLACKBERRY = 105,
  BLACKBERRY_JUICE = 1361,
  BLACKBERRY_PIE = 1706,
  BLACKBERRY_PIE_SLICE = 1726,
  BLACKBERRY_HANDFUL = 3214,
  WATER_PURE = 1371,
  WATER_STAGNANT = 1535,
  WATER_DIRTY = 1368,
  MRE_APPLE = 1402, // TODO = add other MRE types
  MRE01 = 1403,
  MRE02 = 1404,
  MRE03 = 1405,
  MRE04 = 1406,
  MRE05 = 1407,
  MRE06 = 1409,
  MRE07 = 1408,
  MRE08 = 1410,
  MRE09 = 1411,
  MRE10 = 1412,
  MRE11 = 1413,
  MRE12 = 1414,
  SANDWICH_BEAR = 1459,
  STEAK_BEAR = 1451,
  SURVIVAL_BREAD = 1456,
  MEAT_BEAR = 1450,
  COFFEE = 55,
  COFFEE_SUGAR = 71,
  STEAK_RABBIT = 117,
  MEAT_RABBIT = 116,
  SANDWICH_RABBIT = 1457,
  STEW_RABBIT = 118,
  CORN = 107,
  CORN_ROASTED = 1387,
  JERKY_DEER = 21,
  MEAT_VENISON = 20,
  SANDWICH_DEER = 1460,
  STEAK_DEER = 61,
  HONEY = 2192,
  MOONSHINE = 1386,
  COLD_MEDICINE = 1742,
  SURVIVAL_BORSCHT = 1379,
  SANDWICH_WOLF = 1458,
  STEAK_WOLF = 1343,
  MEAT_WOLF = 1342,
  MEAT_ROTTEN = 1381,
  //#endregion

  //#region CONSTRUCTION
  GROUND_TAMPER = 124,
  SHACK = 1433,
  SHACK_SMALL = 1440,
  SHACK_BASIC = 1468,
  SHELTER = 150,
  SHELTER_LARGE = 153,
  SHELTER_UPPER_LARGE = 1897,
  SHELTER_UPPER = 1898,
  FOUNDATION = 1378,
  FOUNDATION_EXPANSION = 2336,
  FOUNDATION_RAMP = 2269,
  FOUNDATION_STAIRS = 2270,
  METAL_GATE = 148,
  DOOR_METAL = 1881,
  DOOR_WOOD = 1435,
  METAL_WALL = 149,
  METAL_WALL_UPPER = 1896,
  DOOR_BASIC = 1470,
  LANDMINE = 74,
  IED = 1699,
  PUNJI_STICKS = 98,
  PUNJI_STICK_ROW = 3580,
  SNARE = 1415,
  ANIMAL_TRAP = 91,
  BARBED_WIRE = 108,
  BARBEQUE = 1447,
  BEE_BOX = 2034,
  CAMPFIRE = 15,
  CANDLE = 1904,
  DEW_COLLECTOR = 97,
  FURNACE = 64,
  LOOKOUT_TOWER = 2272,
  METAL_DOORWAY = 1969,
  REPAIR_BOX = 2792,
  SLEEPING_MAT = 51,
  STORAGE_BOX = 1982,
  STRUCTURE_STAIRS = 154,
  STRUCTURE_STAIRS_UPPER = 1900,
  WORKBENCH = 1891,
  WORKBENCH_WEAPON = 3778,
  BARRICADE = 122,
  //#endregion

  //#region WORN LETTERS
  WORN_LETTER_CHURCH_PV = 1752,
  WORN_LETTER_MISTY_DAM = 1753,
  WORN_LETTER_RUBY_LAKE = 1754,
  WORN_LETTER_WATER_TOWER = 1755,
  WORN_LETTER_TOXIC_LAKE = 1756,
  WORN_LETTER_RADIO = 1757,
  WORN_LETTER_LJ_PV = 1758,
  WORN_LETTER_VILLAS = 1759,
  CHEST_CHURCH_PV = 1760,
  CHEST_MISTY_DAM = 1761,
  CHEST_RUBY_LAKE = 1762,
  CHEST_WATER_TOWER = 1763,
  CHEST_TOXIC_LAKE = 1764,
  CHEST_RADIO = 1765,
  CHEST_LJ_PV = 1766,
  CHEST_VILLAS = 1767,
  //#endregion

  //#region COMPONENT
  SHARD_METAL = 114,
  SHARD_BRASS = 3780,
  SHARD_PLASTIC = 3775,
  GUNPOWDER_REFINED = 3805,
  ALLOY_LEAD = 3779,
  PROTOTYPE_MECHANISM = 3455,
  PROTOTYPE_TRIGGER_ASSEMBLY = 3456,
  PROTOTYPE_RECEIVER = 3457,
  NAIL = 135,
  BACKPACK_FRAME = 1466,
  METAL_BRACKET = 141,
  ANIMAL_FAT = 72,
  FLOUR = 1455,
  WAX = 2193,
  HONEYCOMB = 2203,
  PHONE_DEAD = 2635,
  PHONE_BATTERY = 2637,
  PHONE_CHARGED = 2636,
  CORN_MASH = 1385,
  YEAST = 1445,
  DEER_SCENT = 1462,
  DEER_BLADDER = 1463,
  DUCT_TAPE = 134,
  TRAP_IGNITION_KIT = 2831,
  SALINE = 77,
  WHEAT = 1438,
  TWINE = 142,
  GUN_PART = 1890,
  REPAIR_KIT_GUN = 1895,
  UPGRADE_KIT_GUN = 2419,
  CHARCOAL = 26,
  METAL_BAR = 39,
  //#endregion

  //#region Quest Items
  ANTI_VIRAL_BOTTLE = 2671,
  HANDWRITTEN_NOTE_CAROLINE = 2611,
  ANTI_VIRAL_BOTTLE_EMPTY = 2612,
  GRENADE_SONIC_BROKEN = 3040,
  VIAL_H1Z1_B_PLASMA = 3041,
  VIAL_H1Z1_REDUCER = 2498,
  BATTERIES_AA = 2833,
  BRAIN_TREATED = 2643,
  BRAIN_INFECTED = 2642,
  SYRINGE_INFECTED_BLOOD = 1510,
  EMPTY_SPECIMEN_BAG = 2641,
  DEAD_CELL_PHONE = 2635,
  WEAK_CELL_PHONE_BATTERY = 2637,
  CRACKED_CLIPBOARD = 2610,
  DOCTORS_FILE = 2631,
  WEICHS_WALLET = 2703,
  WEICHS_REPORT = 2633,
  KLAVISK_NOTE = 2632,
  REFRIGERATOR_NOTE = 3075,
  DOCTORS_MEMO = 3076,
  TORN_LETTERHEAD = 2638,
  SMALL_KEY = 2640,
  CRUMPLED_NOTE = 2639,
  //#endregion

  //#region Traps
  TRAP_FIRE = 2812,
  TRAP_FLASH = 2810,
  TRAP_GAS = 2811,
  TRAP_SHOCK = 2832,
  //#endregion

  //#region
  BACKPACK_FRAMED = 2111,
  BACKPACK_SATCHEL = 1432,
  BACKPACK_MILITARY_TAN = 2124,
  BACKPACK_MILITARY_GREEN_CAMO = 2121,
  BACKPACK_BLUE_ORANGE = 2038,
  HELMET_MOTORCYCLE = 2170, // TODO = expand with other default helmet colors
  HAT_CAP = 2102, // TODO = expand with other cap colors
  SHIRT_DEFAULT = 2088, // TODO = expand with other default shirts
  PANTS_DEFAULT = 2177, // TODO = expand with other default pants
  SHIRT_SCRUBS_BLUE = 2553,
  PANTS_SCRUBS_BLUE = 2557,
  SURGEON_MASK_AQUA = 2569,
  CAP_SCRUBS_BLUE = 2560,
  SHIRT_SCRUBS_GRAY = 2555,
  PANTS_SCRUBS_GRAY = 2558,
  CAP_SCRUBS_GRAY = 2561,

  CONVEYS_RED = 2216,
  CONVEYS_BLUE = 2217,
  CONVEYS_WHITE = 2218,
  CONVEYS_DRAGON = 2398,
  CONVEYS_CDN = 2795,
  CONVEYS_NEKOCHAN = 3404,
  CONVEYS_ELLOHIME = 3574,
  HAT_BEANIE = 2162,
  BOOTS_TAN = 2207,
  BOOTS_GRAY_BLUE = 2209,
  SUGAR = 57,
  BATTERY = 1696,
  SPARKPLUGS = 1701,
  SALT = 22,
  LIGHTER = 1436,
  BOW_DRILL = 1452,
  WATER_EMPTY = 1353,
  FUEL_BIOFUEL = 73,
  FUEL_ETHANOL = 1384,
  WOOD_PLANK = 109,
  METAL_SHEET = 46,
  METAL_SCRAP = 48,
  BROKEN_METAL_ITEM = 1354,
  TARP = 155,
  WOOD_LOG = 16,
  WOOD_STICK = 111,
  GROUND_TILLER = 1383,
  FERTILIZER = 25,
  SEED_CORN = 1987,
  SEED_WHEAT = 1988,
  VIAL_EMPTY = 2510,
  SYRINGE_EMPTY = 1508,
  GHILLIE_SUIT = 92,
  GHILLIE_SUIT_TAN = 2570,
  HELMET_TACTICAL = 2172,
  RESPIRATOR = 2148,
  NV_GOGGLES = 1700,
  ALL_PURPOSE_GOGGLES = 1693,
  GUNPOWDER = 11,
  KEVLAR_DEFAULT = 2271,
  ARMOR_PLATED = 2205,
  ARMOR_WOODEN = 2204,
  CLOTH = 23,
  METAL_PIPE = 47,
  GRENADE_SMOKE = 2236,
  GRENADE_FLASH = 2235,
  GRENADE_GAS = 2237,
  GRENADE_HE = 65,
  GRENADE_SCREAM = 3022,
  MAP = 1985,
  COMPASS = 1441,
  FLARE = 1804,
  FLARE_PARACHUTE = 1906,
  FLARE_SMOKE = 1672,
  BACKPACK_RASTA = 2393,
  WAIST_PACK = 1803,
  BELT_POUCH = 1529,
  FANNY_PACK_DEV = 1,
  VEHICLE_KEY = 3460,
  CODED_MESSAGE = 2722,
  AIRDROP_CODE = 2675,
  AIRDROP_TICKET = 1800,
  BANDANA_BASIC = 2323,
  GLOVES_FINGERLESS = 2324,
  HAND_SHOVEL = 1697,
  COMPASS_IMPROVISED = 1444,
  SKINNING_KNIFE = 110,
  RIGGED_LIGHT = 1748,
  SYRINGE_H1Z1_REDUCER = 1464,
  LOCKER_KEY_F1 = 2645,
  LOCKER_KEY_F2 = 2646,
  LOCKER_KEY_F3 = 2647,
  LOCKER_KEY_F4 = 2648,
  EMERGENCY_RADIO = 2273,
  GUN_REPAIR_KIT = 1895,
  WEAPON_REPAIR_KIT = 1467,

  HEADLIGHTS_OFFROADER = 9,
  HEADLIGHTS_PICKUP = 1728,
  HEADLIGHTS_POLICE = 1730,
  HEADLIGHTS_ATV = 2595,

  TURBO_OFFROADER = 90,
  TURBO_PICKUP = 1729,
  TURBO_POLICE = 1731,
  TURBO_ATV = 2727,

  VEHICLE_HOTWIRE = 3458,
  VEHICLE_MOTOR_OFFROADER = 1344,
  VEHICLE_MOTOR_PICKUP = 1712,
  VEHICLE_MOTOR_POLICECAR = 1722,
  VEHICLE_MOTOR_ATV = 2594,

  VEHICLE_HORN = 1858,
  VEHICLE_HORN_POLICECAR = 1735,
  VEHICLE_SIREN_POLICECAR = 1732,

  CONTAINER_VEHICLE_OFFROADER = 1541,
  CONTAINER_VEHICLE_PICKUP = 1783,
  CONTAINER_VEHICLE_POLICECAR = 1723,
  CONTAINER_VEHICLE_ATV = 2728,

  CONTAINER_DROPPED_ITEMS = 3089,

  CONTAINER_STORAGE = 1506,
  CONTAINER_REPAIR_BOX = 2338,
  CONTAINER_WRECKED_VAN = 1476,
  CONTAINER_WRECKED_CAR = 1474,
  CONTAINER_WRECKED_TRUCK = 1475,
  CONTAINER_WEAPONS_LOCKER = 1705,
  CONTAINER_DESK = 1503,
  CONTAINER_STASH = 1698,

  CONTAINER_TOOL_CABINETS = 1507,
  CONTAINER_DUMPSTER = 1490,
  CONTAINER_FILE_CABINET = 1504,
  CONTAINER_LOCKER = 1704,
  CONTAINER_FRIDGE = 1472,
  CONTAINER_OTTOMAN = 1497,
  CONTAINER_DRESSER = 1493,
  CONTAINER_ARMOIRE = 1491,

  // COMBINE THESE
  CONTAINER_CABINETS = 1480,
  CONTAINER_CABINETS_BATHROOM = 1480,
  CONTAINER_CABINETS_CUBE = 1480,
  CONTAINER_CABINETS_KITCHEN = 1480,

  CONTAINER_GARBAGE_CAN = 1500,
  CONTAINER_FURNACE = 1711,
  CONTAINER_BARBEQUE = 1477,
  CONTAINER_CAMPFIRE = 1473,
  CONTAINER_DEW_COLLECTOR = 1540,
  CONTAINER_ANIMAL_TRAP = 1539,
  CONTAINER_BEE_BOX = 2035,
  CONTAINER_DRUG_CABINET = 2525,
  CONTAINER_MEDICAL_STATION = 2524,
  CONTAINER_HOSPITAL_DESK = 2677,
  CONTAINER_GROSSING_STATION = 2529,
  CONTAINER_HOSPITAL_REFRIGERATOR = 1472,
  CONTAINER_HOSPITAL_CABINET = 2676,
  CONTAINER_MILITARY_CRATE = 1501,
  CONTAINER_LOOT_CACHE = 9069,

  CONTAINER_WASHING_MACHINE = 1887,
  CONTAINER_DRYER = 1888,

  // Skin ref
  CAMO_TAN_FLANNEL_SHIRT = 2030,
  BLUE_FLANNEL_SHIRT = 2054,
  BROWN_FLANNEL_SHIRT = 2055,
  GREEN_FLANNEL_SHIRT = 2056,
  RED_FLANNEL_SHIRT = 2057,
  PAISLEY_FLANNEL_SHIRT = 2184,
  CAMO_GREEN_FLANNEL_SHIRT = 2187,
  POLICE_SHIRT = 2346,
  BASIC_HOODIE = 2373,
  BLACK_ORANGE_HOODIE = 2374,
  TWITCH_HOODIE = 2375,
  BLUE_BLACK_HOODIE = 2376,
  DOA_HOODIE = 2377,
  PRO_GRAMER_HOODIE = 2378,
  PARAMEDIC_UNIFORM = 2535,
  DRAGON_LODGE_PARKA = 3033,
  FLOWER_PRINT_PANTS = 2280,
  POLICE_SLACKS = 2347,
  LEGGINGS = 2364,
  BONE_LEGGINGS = 2365,
  MUSCLE_LEGGINGS = 2366,
  PARAMEDIC_SLACKS = 2534,
  TWIN_GALAXIES_PANTS = 3875,
  STARS_STRIPES_SHORTS = 2404,
  AVIATOR_CAP = 2058,
  BLACK_BEANIE = 2162,
  POLICE_HAT = 2344,
  TOXIC_BODY_ARMOR = 2477,
  DEAD_END_ARMOR = 2860,
  EZW_ARMORED_CHAMPIONSHIP_BELT = 3125,
  EZW_ARMORED_SHOULDERPADS = 3126,
  POLICE_BODY_ARMOR = 2274,
  GORILLA_WARFARE = 3631,
  ARACHNID = 3721,
  DEFAULT = 2170,
  INFERNAL_DEMON_MASK = 3862,
  HOLIDAY_HAT = 2887,
  MASK_OF_JESTER = 3366,
  PATCHWORK_RUDOLPH_HELMET = 2817,
  WASTELAND_SKULL_HELMET = 3064,
  EZW_SPIKED_HELMET = 3124,
  DRAGON_MOTORCYCLE_HELMET = 2828,
  CIGAR_HOG_MASK = 2396,
  WHITE_UNICORN_FULL_HELMET = 3439,
  STAR_SPANGLED_HAT = 3470,
  PUMPKIN_MASK = 2745,
  SCARECROW_MASK = 2750,
  MILITARY_DEFAULT = 2124,
  RASTA_BACKPACK = 2393,
  PINK_SKULLS_SURVIVOR_BACKPACK = 3046,
  SNIPER_MILITARY_BACKPACK = 3169,
  FULLY_GEARED_EXPLORER_BACKPACK = 4009,
  EVIL_CLOWN_GLASSES = 2253,
  DEFAULT_GOGGLES = 1693,
  WHITE_BIKER_GLASSES = 2252,
  STEAMPUNK_GOGGLES = 2954,
  HAPPY_SKULL_SCRUBS_SHIRT = 2802,
  HAPPY_SKULL_SCRUBS_CAP = 2805,
  HAPPY_SKULL_SCRUBS_PANTS = 2808,
  PINK_GATORS = 2567,
  DOOMED_PUFFY_JACKET = 3977,

  REWARD_SET_WOODLAND_GHILLIE = 2725,
  REWARD_SET_RED_FACE_BANDANA = 2326,
  REWARD_SET_EVIL_CLOWN_BANDANA = 2327,
  REWARD_SET_BLUE_FACE_BANDANA = 2328,
  REWARD_SET_CAMO_FACE_BANDANA = 2329,
  REWARD_SET_AMERICAN_FACE_BANDANA = 2330,
  REWARD_SET_PINK_FACE_BANDANA = 2331,
  REWARD_SET_SKULL_FACE_BANDANA = 2332,
  SKIN_WOODLAND_GHILLIE_SUIT_BOOTS = 2679,
  SKIN_GREEN_GLOVES = 2669,
  SKIN_RED_FACE_BANDANA = 2305,
  SKIN_RED_BIKER_SHADES = 2296,
  SKIN_EVIL_CLOWN_FACE_BANDANA = 2303,
  SKIN_EVIL_CLOWN_GLASSES = 2298,
  SKIN_BLUE_FACE_BANDANA = 2301,
  SKIN_BLUE_BIKER_SHADES = 2293,
  SKIN_CAMO_FACE_BANDANA = 2302,
  SKIN_GREEN_BIKER_SHADES = 2294,
  SKIN_AMERICAN_FACE_BANDANA = 2307,
  SKIN_WHITE_BIKER_SHADES = 2297,
  SKIN_PINK_FACE_BANDANA = 2304,
  SKIN_PINK_BIKER_SHADES = 2295,
  SKIN_SKULL_FACE_BANDANA = 2306,
  SKIN_BLACK_BIKER_SHADES = 2292,
  REWARD_CRATE_SHOWDOWN = 2761,
  REWARD_CRATE_ALPHA_LAUNCH = 1797,
  REWARD_CRATE_PREDATOR_GOLD = 3211,
  REWARD_CRATE_PREDATOR_SILVER = 3210,
  REWARD_CRATE_PREDATOR_BRONZE = 3209,
  REWARD_CRATE_PREDATOR = 3207,
  REWARD_CRATE_EZW_GOLD = 3122,
  REWARD_CRATE_EZW_SILVER = 3121,
  REWARD_CRATE_EZW_BRONZE = 3120,
  REWARD_CRATE_EZW = 3118,
  REWARD_CRATE_RENEGADE_GOLD = 2893,
  REWARD_CRATE_RENEGADE_SILVER = 2892,
  REWARD_CRATE_RENEGADE_BRONZE = 2891,
  REWARD_CRATE_RENEGADE = 2836,
  REWARD_CRATE_WASTELAND_GOLD = 3028,
  REWARD_CRATE_WASTELAND_SILVER = 3027,
  REWARD_CRATE_WASTELAND_BRONZE = 3026,
  REWARD_CRATE_WASTELAND = 2939,
  REWARD_CRATE_BR_1 = 2031,
  REWARD_CRATE_BR_2 = 2350,
  REWARD_CRATE_INVITATIONAL = 2436,
  REWARD_CRATE_WEARABLES = 2009,
  REWARD_CRATE_MARAUDER = 2276,
  REWARD_CRATE_MERCENARY = 2432,
  REWARD_CRATE_RONIN = 3501,
  REWARD_CRATE_INVITATIONAL_2016_GOLD = 3573,
  REWARD_CRATE_INVITATIONAL_2016_SILVER = 3572,
  REWARD_CRATE_INVITATIONAL_2016_BRONZE = 3571,
  REWARD_CRATE_INVITATIONAL_2016 = 3569,
  REWARD_CRATE_INFERNAL_GOLD = 3824,
  REWARD_CRATE_INFERNAL_SILVER = 3823,
  REWARD_CRATE_INFERNAL_BRONZE = 3822,
  REWARD_CRATE_INFERNAL = 3821,
  MYSTERY_BAG_KOTK = 3239,
  KOTK_ELITE_BAG = 3240,
  SKIRMISH_SMALL_FIREARMS = 3274,
  SKIRMISH_SHOTTIES_SNIPERS = 3365,
  SKIRMISH_IRONMAN = 3447,
  SKIRMISH_REANIMATED = 3523,
  SKIRMISH_SHOTTIES_SNIPERS_2 = 3633,
  MYSTERY_BAG_1 = 1840,
  ELITE_BAG = 1841,
  MYSTERY_BAG_2 = 1879,
  ELITE_BAG_HARDCORE = 1880,
  MYSTERY_BAG_V2 = 2033
}

export enum WeaponDefinitionIds {
  WEAPON_BOW_MAKESHIFT = 113,
  WEAPON_BOW_RECURVE = 1399,
  WEAPON_CROSSBOW = 1414,
  WEAPON_BOW_WOOD = 1387,
  WEAPON_SHOTGUN = 1374,
  WEAPON_308 = 1373,
  WEAPON_NAGAFENS_RAGE = 1450,
  WEAPON_REAPER = 1452,
  WEAPON_FROSTBITE = 1448,
  WEAPON_BLAZE = 1449,
  WEAPON_PURGE = 1451,

  WEAPON_AK47 = 1405,
  WEAPON_AR15 = 6,
  WEAPON_MAGNUM = 1388,
  WEAPON_R380 = 1400,
  WEAPON_M9 = 1401,
  WEAPON_1911 = 2,
  WEAPON_CROWBAR = 9,
  WEAPON_HAMMER = 1396,
  WEAPON_WRENCH = 1415
}

export enum Skins_Shirt {
  CAMO_TAN_FLANNEL_SHIRT = 2030,
  BLUE_FLANNEL_SHIRT = 2054,
  BROWN_FLANNEL_SHIRT = 2055,
  GREEN_FLANNEL_SHIRT = 2056,
  RED_FLANNEL_SHIRT = 2057,
  PAISLEY_FLANNEL_SHIRT = 2184,
  CAMO_GREEN_FLANNEL_SHIRT = 2187,
  POLICE_SHIRT = 2346,
  BASIC_HOODIE = 2373,
  BLACK_ORANGE_HOODIE = 2374,
  TWITCH_HOODIE = 2375,
  BLUE_BLACK_HOODIE = 2376,
  DOA_HOODIE = 2377,
  PRO_GRAMER_HOODIE = 2378,
  PARAMEDIC_UNIFORM = 2535,
  SHIRT_DEFAULT = 2088,
  DRAGON_LODGE_PARKA = 3033
}

export enum Skins_Pants {
  FLOWER_PRINT_PANTS = 2280,
  POLICE_SLACKS = 2347,
  LEGGINGS = 2364,
  BONE_LEGGINGS = 2365,
  MUSCLE_LEGGINGS = 2366,
  PARAMEDIC_SLACKS = 2534,
  PANTS_DEFAULT = 2177,
  TWIN_GALAXIES_PANTS = 3875,
  STARS_STRIPES_SHORTS = 2404
}

export enum Skins_Beanie {
  AVIATOR_CAP = 2058,
  BLACK_BEANIE = 2162,
  POLICE_HAT = 2344
}

export enum Skins_Cap {
  CAMO_GREEN_OUTBACK_HAT = 2046,
  TAN_CANVAS_OUTBACK_HAT = 2066,
  BROWN_LEATHER_OUTBACK_HAT = 2067,
  HAT_CAP = 2102
}

export enum Skins_MotorHelmet {
  GORILLA_WARFARE = 3631,
  ARACHNID = 3721,
  DEFAULT = 2170,
  WASTELAND_SKULL_HELMET = 3064,
  EZW_SPIKED_HELMET = 3124,
  STAR_SPANGLED_HAT = 3470,
  PUMPKIN_MASK = 2745
  /*SCARECROW_MASK = 2750,
  BLUE_RACING_HELMET = 2042,
  WHITE_STRIPED_HELMET = 2043,
  ZIMMS_YELLOW_RACING_HELMET = 2044,
  ORANGE_RACING_HELMET = 2062,
  RED_BLUE_RACING_HELMET = 2063,
  PATRIOTIC_HELMET = 2076,
  GREEN_WHITE_RACING_HELMET = 2077,
  ZIMMS_RED_RACING_HELMET = 2078,
  BLACK_HELMET = 2168,
  GREY_HELMET = 2169,
  WHITE_HELMET = 2171,
  RASTA_HELMET = 2829,
  RAINBOW_SWIRL = 2830,
  ANARCHY_HELMET = 2839,
  HEAVY_ASSAULT_FULL_HELMET = 3181,
  KITSUNE_PLATED_HELMET = 3409,
  FIERY_SPIKED_HELMET = 3451,
  DR_DISRESPECT_HELMET = 3545,
  ANGRY_PUG_HELMET = 3546,
  INFERNAL_DEMON_MASK = 3862,
  HOLIDAY_HAT = 2887,
  MASK_OF_JESTER = 3366,
  PATCHWORK_RUDOLPH_HELMET = 2817,
  DRAGON_MOTORCYCLE_HELMET = 2828,
  CIGAR_HOG_MASK = 2396,
  WHITE_UNICORN_FULL_HELMET = 3439
  BLUE_RABBIT_MASK = 3159,
  WHITE_UNICORN_FULL_HELMET = 3439,
  BLACK_UNICORN_FULL_HELMET = 3440,
  FRANKENSWINE_HELMET = 3732,
  FULL_METAL_PUMPKIN_MASK = 3739 */
}
export enum Skins_TacticalHelmet {
  DEFAULT_TACTICAL_HELMET = 2172,
  TECH_TACTICAL_HELMET = 3167,
  BLUE_CAMO_GOGGLES_TACTICAL_HELMET = 2045
  /*CAMO_TACTICAL_HELMET = 2290,
  EAGLE_TACTICAL_HELMET = 2838,
  FIREFIGHTER_TACTICAL_HELMET = 3414,
  SNIPER_TACTICAL_HELMET = 3487 
  PATCHWORK_RUDOPH_HELMET = 2817*/
}
export enum Skins_Respirator {
  DEFAULT_RESPIRATOR = 2148,
  METAL_FULL_FASK_MASK = 2291
  //SKULL_FULL_FACE_RESPIRATOR = 2289,
}
export enum Skins_Kevlar {
  KEVLAR_DEFAULT = 2271,
  TOXIC_BODY_ARMOR = 2477,
  POLICE_BODY_ARMOR = 2274,
  DEAD_END_ARMOR = 2860,
  EZW_ARMORED_SHOULDERPADS = 3126
  /*CAMO_BODY_ARMOR = 2546,
  PINK_SKULL_BODY_ARMOR = 2547,
  SUMMIT1G_BODY_ARMOR = 2775,
  SXYHXY_BODY_ARMOR = 2784,
  TECH_TACTICAL_BODY_ARMOR = 3175,
  KITSUNE_TACTICAL_BODY_ARMOR = 3413,
  SNIPER_LAMINATED_BODY_ARMOR = 3483,
  RED_BONE_BODY_ARMOR = 3549,
  DESERT_WARFARE_TACTICAL_BODY_ARMOR = 3587,
  ARACHNID_TACTICAL_BODY_ARMOR = 3722, 
  EZW_ARMORED_CHAMPIONSHIP_BELT = 3125 */
}
export enum Skins_Military {
  MILITARY_DEFAULT = 2124,
  BACKPACK_RASTA = 2393,
  FULLY_GEARED_EXPLORER_BACKPACK = 4009
  /*PINK_SKULLS_SURVIVOR_BACKPACK = 3046,
  SNIPER_MILITARY_BACKPACK = 3169
  BLUE_CAMO_MILITARY_BACKPACK = 1602,
  GREEN_CAMO_MILITARY_BACKPACK = 1603,
  TAN_CAMO_MILITARY_BACKPACK = 1606,
  BLACK_MILITARY_PACKPACK = 2118,
  BLUE_MILITARY_BACKPACK = 2119,
  RED_AND_BLACK_MILITARY_BACKPACK = 2123,
  SHOWDOWN_MILITARY_BACKPACK = 2777,
  CROWN_MILITARY_BACKPACK = 2778 */
}
export enum Skins_Backpack {
  BACKPACK_DEFAULT = 2038
  /*CAMO_BACKPACK = 2051,
  GRAY_YELLOW_BACKPACK = 2072,
  BLACK_BACKPACK = 2112,
  BLUE_BACKPACK = 2113,
  BLUE_GRAY_BACKPACK = 2114,
  GREEN_BACKPACK = 2115,
  ORANGE_BACKPACK = 2116,
  RED_BACKPACK = 2117,
  FRANKENSWINE_BACKPACK = 3742, */
}
export enum Skins_Glasses {
  EVIL_CLOWN_GLASSES = 2253,
  DEFAULT_GOGGLES = 1693,
  WHITE_BIKER_GLASSES = 2252,
  STEAMPUNK_GOGGLES = 2954
}
export enum Skins_Bandana {
  DEFAULT_BANDANA = 2323
  /*BLUE_BANDANA = 2256,
  CAMO_BANDANA = 2257,
  EVIL_CLOWN_BANDANA = 2258,
  PINK_BANDANA = 2259,
  RED_BANDANA = 2260,
  SKULL_BANDANA = 2261,
  AMERICAN_BANDANA = 2262,
  CHAOS_BANDANA = 2923,
  RASTA_BANDANA = 2924,
  TAN_GHILLIE_BANDANA = 2925,
  GREEN_GHILLIE_BANDANA = 2926,
  GOLDEN_DRAGON_BANDANA = 2927,
  BARBED_WIRE_BANDANA = 2928,
  YELLOW_PLAID_BANDANA = 2929,
  FLAMING_SKULL_BANDANA = 2930*/
}
export enum Skins_Conveys {
  CONVEYS_BLUE = 2217,
  CONVEYS_RED = 2216,
  CONVEYS_WHITE = 2218,
  CONVEYS_DRAGON = 2398,
  CONVEYS_CDN = 2795,
  CONVEYS_NEKOCHAN = 3404,
  CONVEYS_ELLOHIME = 3574
}
export enum Skins_Boots {
  BOOTS_TAN = 2207
  /*BOOTS_BROWN = 2206,
  BOOTS_GRAY = 2208,
  BOOTS_GRAY_BLUE = 2209,
  BOOTS_GREEN_SPLATTER = 2281,
  BOOTS_CHEETAH_CAMO = 2282,
  BOOTS_TAN_GHILLE = 2613,
  BOOTS_WOODLAND_GHILLE = 2616,
  BOOTS_TEAL_COMBAT = 2618,
  BOOTS_HAPPY_FACE = 2619,
  BOOTS_PATRIOTIC = 2620,
  BOOTS_PURPLE = 2621,
  BOOTS_HEAVY_ASSAULT = 3180*/
}
export enum Skins_Sniper {
  DEFAULT_SNIPER = 1373
  /*BLACK_SNIPER = 2900,
  GREEN_CAMO_SNIPER = 2901,
  TAN_DIGITAL_CAMO_SNIPER = 2902,
  GRAFFITI_SNIPER = 2906,
  DRAGON_LODGE_SNIPER = 2907,
  PATRIOTIC_SNIPER = 2908,
  RAINBOW_SWIRL_SNIPER = 2909,
  PREDATOR_SNIPER = 3172,*/
}
export enum Skins_Shotgun {
  DEFAULT_SHOTGUN = 1374
  /*TOXIC_SHOTGUN = 2446,
  COMBAT_SHOTGUN = 2586,
  WILD_STYLE_SHOTGUN = 2597,
  GREEN_DAWN_SHOTGUN = 2664,
  RAINBOW_SWIRL_SHOTGUN = 3057,
  TIGER_BLOOD_SHOTGUN = 3123,
  PREDATOR_SHOTGUN = 3165,
  NEKO_CHAN_SHOTGUN = 3477,
  INFERNAL_SHOTGUN = 3720,
  FOUNDERS_SHOTGUN = 3797*/
}
export enum Skins_AK47 {
  DEFAULT_AK47 = 2229
  /*TOXIC_AK47 = 2480,
  WILDSTYLE_AK47 = 2600,
  GREEN_DAWN_AK47 = 2662,
  RAINBOW_SWIRL_AK47 = 3055,
  DESERT_WARFARE_AK47 = 3401,*/
}
export enum Skins_AR15 {
  DEFAULT_AR15 = 10
  /*MERCENARY_AR15 = 2592,
  PATRIOTIC_AR15 = 2593,
  WILD_STYLE_AR15 = 2601,
  GREEN_DAWN_AR15 = 2666,
  SHOWDOWN_AR15 = 2781,
  SHOWDOWN_GOLD_AR15 = 2788,
  ANODIZED_AR15 = 2789,
  LIGHTNING_AR15 = 2834,
  BLUE_WHITE_AR15 = 2835,
  RAINBOW_SWIRL_AR15 = 3056,
  PREDATOR_AR15 = 3179,
  IREZUMI_DRAGON_AR15 = 3475,
  NINJA_AR15 = 3586,*/
}

export enum Effects {
  Smoke_Orange = 3621,
  Smoke_Green = 3622,
  Smoke_Purple = 3623,
  Smoke_Yellow = 3624,
  Smoke_LimeGreen = 4537,
  Smoke_Red = 4538,
  Smoke_Blue = 4539,
  Smoke_Teal = 4540,
  Smoke_Magenta = 4541,
  TEST_XYZ_loop = 1,
  TEST_XYZ = 2,
  TEST_XYZ_Mesh = 3,
  TEST_MipMaps = 4,
  TEST_Mesh_Sphere = 5,
  TEST_Mesh_Hemisphere = 6,
  TEST_NormalMap_Sphere = 7,
  TEST_Null = 8,
  TEST_Irradience_Spheres = 9,
  TEST_Number1 = 21,
  TEST_Number2 = 22,
  TEST_Number3 = 23,
  TEST_Number4 = 24,
  TEST_Number5 = 25,
  TEST_Number6 = 26,
  TEST_Number7 = 27,
  TEST_Number8 = 28,
  EFX_Blowing_SandLeaves_Tan_Flat = 96,
  EFX_Blowing_SandLeaves_Tan = 97,
  PFX_Eyes_Red = 98,
  PFX_Impact_BulletLight_Default = 99,
  PFX_Mzl_PistolBase = 100,
  PFX_Mzl_PistolBase_IronSight = 101,
  PFX_Mzl_Magnum = 102,
  PFX_Mzl_Magnum_IronSight = 103,
  PFX_Mzl_Shotgun_PumpAction = 105,
  PFX_Mzl_Shotgun_PumpAction_Ironsight = 106,
  VEH_Death_OffRoader = 135,
  EFX_SnowFalling_01 = 150,
  EFX_SmokePlume_01 = 156,
  EFX_Ash_Area = 160,
  EFX_Dust_Floating_Area = 184,
  EFX_Candle_Flame_01 = 185,
  EFX_Candle_Flame_02 = 186,
  EFX_Candle_Flame_03 = 187,
  EFX_Bees_BeeHiveBox = 188,
  PFX_Bee_Swarm_Attack = 189,
  PFX_Fire_Molotov = 190,
  MAT_Molotov = 191,
  PFX_Fire_Molotov_Persist = 192,
  PFX_Damage_Crate_01m = 163,
  PFX_Damage_Sign_Stop = 164,
  PFX_Damage_GlassWindow_House = 165,
  PFX_Impact_BulletLight_Asphalt = 168,
  PFX_Fire_Torch = 169,
  PFX_Fire_Torch_Blue = 183,
  PFX_Flare = 170,
  MAT_Engine_Idle_OffRoader = 171,
  VEH_Engine_Idle_OffRoader = 193,
  VEH_Engine_Thrust_OffRoader = 172,
  VEH_Headlight_OffRoader = 173,
  VEH_Lights_CargoContainer = 271,
  VEH_Lights_Crate = 272,
  VEH_Headlight_OffRoader_wShadows = 273,
  VEH_Lights_C_130 = 274,
  VEH_SirenLight_PoliceCar = 275,
  VEH_Brakes_OffRoader = 174,
  VEH_Dust_OffRoader_Generic = 175,
  VEH_Dust_OffRoader_Dirt = 176,
  VEH_Dust_OffRoader_Grass = 177,
  PFX_Mzl_AssaultRifle = 178,
  PFX_Mzl_AssaultRifle_Ironsight = 179,
  VEH_Damage_OffRoader_Stage03 = 180,
  VEH_Damage_OffRoader_Stage02 = 181,
  VEH_Damage_OffRoader_Stage01 = 182,
  VEH_Engine_Idle_PoliceCar = 277,
  VEH_Engine_Thrust_PoliceCar = 278,
  VEH_Engine_Boost_PoliceCar = 279,
  VEH_Headlight_PoliceCar = 280,
  VEH_Headlight_PoliceCar_wShadows = 281,
  VEH_Brakes_PoliceCar = 282,
  VEH_Damage_PoliceCar_Stage03 = 283,
  VEH_Damage_PoliceCar_Stage02 = 284,
  VEH_Damage_PoliceCar_Stage01 = 285,
  VEH_Death_PoliceCar = 286,
  VEH_Dust_PoliceCar_Generic = 287,
  VEH_Dust_PoliceCar_Dirt = 288,
  VEH_Dust_PoliceCar_Grass = 289,
  VEH_Engine_Idle_PickupTruck = 317,
  VEH_Engine_Thrust_PickupTruck = 318,
  VEH_Engine_Boost_PickupTruck = 319,
  VEH_Headlight_PickupTruck = 320,
  VEH_Headlight_PickupTruck_wShadows = 321,
  VEH_Brakes_PickupTruck = 322,
  VEH_Damage_PickupTruck_Stage03 = 323,
  VEH_Damage_PickupTruck_Stage02 = 324,
  VEH_Damage_PickupTruck_Stage01 = 325,
  VEH_Death_PickupTruck = 326,
  VEH_Dust_PickupTruck_Generic = 327,
  VEH_Dust_PickupTruck_Dirt = 328,
  VEH_Dust_PickupTruck_Grass = 329,
  PFX_Damage_Barricade01 = 241,
  PFX_Death_Barricade01 = 242,
  MAT_Impact_OffRoader = 300,
  PFX_Impact_OffRoader_Generic = 301,
  PFX_Impact_OffRoader_Flesh = 302,
  PFX_Impact_OffRoader_Zombie = 303,
  PFX_Trail_OffRoader_Zombie = 304,
  MAT_Engine_Idle_ATV = 351,
  VEH_Engine_Idle_ATV = 352,
  VEH_Engine_Thrust_ATV = 353,
  VEH_Engine_Boost_ATV = 354,
  VEH_Headlight_ATV_wShadows = 355,
  VEH_Brakes_ATV = 356,
  VEH_Death_ATV = 357,
  VEH_Damage_ATV_Stage03 = 358,
  VEH_Damage_ATV_Stage02 = 359,
  VEH_Damage_ATV_Stage01 = 360,
  MAT_WheelDust_ATV = 361,
  VEH_Dust_ATV_Generic = 362,
  VEH_Dust_ATV_Dirt = 363,
  VEH_Dust_ATV_Grass = 364,
  VEH_Dust_ATV_Water = 365,
  VEH_Dust_ATV_Water_Idle = 366,
  MAT_Impact_ATV = 367,
  PFX_Trail_Projectile_Arrow_Regular = 500,
  PFX_Trail_Projectile_Bullet_Small_1P = 501,
  PFX_Trail_Projectile_Arrow_Flaming = 502,
  PFX_Impact_TreeLeaves_Hazel = 701,
  PFX_Impact_TreeLeaves_Hazel_small = 702,
  PFX_Impact_TreeLeaves_Blackberry = 703,
  PFX_Impact_TreeLeaves_DevilClub = 704,
  PFX_Impact_TreeLeaves_VineMaple = 705,
  MAT_BulletLight = 1000,
  MAT_BulletHeavy = 1007,
  MAT_BulletShotgun = 1006,
  MAT_Blade = 1001,
  MAT_Blade_ForehandSlash = 1011,
  MAT_Blade_BackhandSlash = 1012,
  MAT_Blade_ForehandChop = 1013,
  MAT_Blade_BackhandChop = 1014,
  MAT_Blade_ForehandUppercut = 1015,
  MAT_Blade_ForwardStab = 5115,
  MAT_Guitar = 1016,
  MAT_Guitar_ForehandSlash = 1021,
  MAT_Guitar_BackhandSlash = 1022,
  MAT_Guitar_ForehandChop = 1023,
  MAT_Guitar_BackhandChop = 1024,
  MAT_Guitar_ForehandUppercut = 1025,
  MAT_Guitar_ForwardStab = 1026,
  MAT_Torch = 1002,
  MAT_Knife = 1003,
  MAT_Fists = 1004,
  MAT_Fists_RightHook = 1041,
  MAT_Fists_LeftHook = 1042,
  MAT_Fists_RightStraight = 1043,
  MAT_Fists_LeftStraight = 1044,
  MAT_Fists_RightUppercut = 1045,
  MAT_Fists_LeftUppercut = 1046,
  MAT_Arrow = 1005,
  MAT_Arrow_Flaming = 1008,
  PFX_Impact_BulletLight_Metal = 1143,
  PFX_Impact_BulletLight_Metal_Vehicle = 1144,
  PFX_Impact_BulletLight_Dirt = 1148,
  PFX_Impact_BulletLight_Rubber = 1150,
  PFX_Impact_BulletLight_Flesh = 1165,
  PFX_Impact_BulletLight_Zombie = 1166,
  MAT_WheelDust_OffRoader = 1067,
  FX_Fire_Barrel = 1202,
  EFX_Fire_Barrel = 1203,
  EFX_Fire_Dumpster = 1204,
  EFX_Fire_PlayerStructures = 1214,
  PFX_Fire_Person = 1205,
  PFX_Fire_Zombie_loop = 1206,
  EFX_Fire_Campfire = 1207,
  EFX_Fire_Campfire_Smoldering = 1208,
  EFX_Fire_TrashCan_Small = 1209,
  EFX_Light_StreetLight = 1210,
  EFX_Light_StreetLight_wShadows = 1211,
  PFX_Fire_Person_loop = 1212,
  PFX_Fire_Zombie = 1213,
  P2P_HealingBeam = 1262,
  PFX_Impact_BulletLight_Concrete = 1290,
  PFX_Impact_BulletLight_Wood = 1291,
  PFX_Impact_BulletLight_Glass = 1297,
  PFX_Impact_BulletLight_Grass = 1327,
  PFX_Impact_Blade_Flesh = 1600,
  PFX_Impact_Blade_Concrete = 1601,
  PFX_Impact_Blade_Dirt = 1602,
  PFX_Impact_Blade_Glass = 1603,
  PFX_Impact_Blade_Grass = 1604,
  PFX_Impact_Blade_Metal = 1605,
  PFX_Impact_Blade_Rock = 1606,
  PFX_Impact_Blade_Wood = 1607,
  PFX_Impact_Blade_Zombie = 1608,
  PFX_Impact_Blade_Water = 1609,
  PFX_Impact_Blade_Metal_Vehicle = 1610,
  PFX_Impact_Knife_Flesh = 1620,
  PFX_Impact_Knife_Concrete = 1621,
  PFX_Impact_Knife_Dirt = 1622,
  PFX_Impact_Knife_Glass = 1623,
  PFX_Impact_Knife_Grass = 1624,
  PFX_Impact_Knife_Metal = 1625,
  PFX_Impact_Knife_Rock = 1626,
  PFX_Impact_Knife_Wood = 1627,
  PFX_Impact_Knife_Zombie = 1628,
  PFX_Impact_Knife_Water = 1629,
  PFX_Impact_Knife_Metal_Vehicle = 1630,
  PFX_Impact_Torch_Flesh = 1640,
  PFX_Impact_Torch_Concrete = 1641,
  PFX_Impact_Torch_Dirt = 1642,
  PFX_Impact_Torch_Glass = 1643,
  PFX_Impact_Torch_Grass = 1644,
  PFX_Impact_Torch_Metal = 1645,
  PFX_Impact_Torch_Rock = 1646,
  PFX_Impact_Torch_Wood = 1647,
  PFX_Impact_Torch_Zombie = 1648,
  PFX_Impact_Torch_Water = 1649,
  PFX_Impact_Torch_Metal_Vehicle = 1650,
  PFX_Impact_Fists_Flesh = 1660,
  PFX_Impact_Fists_Concrete = 1661,
  PFX_Impact_Fists_Dirt = 1662,
  PFX_Impact_Fists_Glass = 1663,
  PFX_Impact_Fists_Grass = 1664,
  PFX_Impact_Fists_Metal = 1665,
  PFX_Impact_Fists_Rock = 1666,
  PFX_Impact_Fists_Wood = 1667,
  PFX_Impact_Fists_Zombie = 1668,
  PFX_Impact_Fists_Metal_Vehicle = 1670,
  PFX_Impact_Arrow_Flesh = 1680,
  PFX_Impact_Arrow_Concrete = 1681,
  PFX_Impact_Arrow_Dirt = 1682,
  PFX_Impact_Arrow_Glass = 1683,
  PFX_Impact_Arrow_Grass = 1684,
  PFX_Impact_Arrow_Metal = 1685,
  PFX_Impact_Arrow_Rock = 1686,
  PFX_Impact_Arrow_Wood = 1687,
  PFX_Impact_Arrow_Zombie = 1688,
  PFX_Impact_Arrow_Water = 1689,
  PFX_Impact_Arrow_Metal_Vehicle = 1690,
  PFX_Impact_Arrow_Rubber = 1691,
  PFX_Flashlight_1P = 1705,
  PFX_Flashlight_3P = 1706,
  PFX_Impact_Guitar_Flesh = 1720,
  PFX_Impact_Guitar_Concrete = 1721,
  PFX_Impact_Guitar_Dirt = 1722,
  PFX_Impact_Guitar_Glass = 1723,
  PFX_Impact_Guitar_Grass = 1724,
  PFX_Impact_Guitar_Metal = 1725,
  PFX_Impact_Guitar_Rock = 1726,
  PFX_Impact_Guitar_Wood = 1727,
  PFX_Impact_Guitar_Zombie = 1728,
  PFX_Impact_Guitar_Water = 1729,
  PFX_Impact_Guitar_Metal_Vehicle = 1730,
  PFX_Impact_Blade_Zombie_ForehandSlash = 1811,
  PFX_Impact_Blade_Zombie_BackhandSlash = 1812,
  PFX_Impact_Blade_Zombie_ForehandChop = 1813,
  PFX_Impact_Blade_Zombie_BackhandChop = 1814,
  PFX_Impact_Blade_Zombie_ForehandUppercut = 1815,
  PFX_Impact_Blade_Zombie_ForwardStab = 5114,
  PFX_Impact_Blade_Human_ForehandSlash = 1816,
  PFX_Impact_Blade_Human_BackhandSlash = 1817,
  PFX_Impact_Blade_Human_ForehandChop = 1818,
  PFX_Impact_Blade_Human_BackhandChop = 1819,
  PFX_Impact_Blade_Human_ForehandUppercut = 1820,
  PFX_Impact_Blade_Human_ForwardStab = 5113,
  PFX_Impact_Guitar_Zombie_ForehandSlash = 1823,
  PFX_Impact_Guitar_Zombie_BackhandSlash = 1824,
  PFX_Impact_Guitar_Zombie_ForehandChop = 1825,
  PFX_Impact_Guitar_Zombie_BackhandChop = 1826,
  PFX_Impact_Guitar_Zombie_ForehandUppercut = 1827,
  PFX_Impact_Guitar_Zombie_ForwardStab = 1828,
  PFX_Impact_Guitar_Human_ForehandSlash = 1829,
  PFX_Impact_Guitar_Human_BackhandSlash = 1830,
  PFX_Impact_Guitar_Human_ForehandChop = 1831,
  PFX_Impact_Guitar_Human_BackhandChop = 1832,
  PFX_Impact_Guitar_Human_ForehandUppercut = 1833,
  PFX_Impact_Guitar_Human_ForwardStab = 1834,
  PFX_Impact_Fists_Zombie_RightHook = 1841,
  PFX_Impact_Fists_Zombie_LeftHook = 1842,
  PFX_Impact_Fists_Zombie_RightStraight = 1843,
  PFX_Impact_Fists_Zombie_LeftStraight = 1844,
  PFX_Impact_Fists_Zombie_RightUppercut = 1845,
  PFX_Impact_Fists_Zombie_LeftUppercut = 1846,
  PFX_Impact_Fists_Flesh_RightHook = 1851,
  PFX_Impact_Fists_Flesh_LeftHook = 1852,
  PFX_Impact_Fists_Flesh_RightStraight = 1853,
  PFX_Impact_Fists_Flesh_LeftStraight = 1854,
  PFX_Impact_Fists_Flesh_RightUppercut = 1855,
  PFX_Impact_Fists_Flesh_LeftUppercut = 1856,
  PFX_Impact_ExplosionGround_Dirt_01m_DEPRECATED = 1867,
  PFX_Impact_Explosion_FragGrenade_Dirt_08m = 1873,
  PFX_Impact_Explosion_ExplosiveArrow_Dirt_08m = 1874,
  PFX_Impact_Explosion_Landmine_Dirt_10m = 1875,
  PFX_Impact_Explosion_AirdropBomb_Dirt_10m = 1876,
  PFX_Impact_Explosion_FragGrenade_Metal_08m = 2082,
  PFX_Impact_Explosion_ExplosiveArrow_Metal_08m = 2083,
  PFX_Impact_Explosion_Landmine_Metal_10m = 2084,
  PFX_Impact_Explosion_AirdropBomb_Metal_10m = 2085,
  PFX_Impact_ExplosionGround_Concrete_02m_DEPRECATED = 2104,
  PFX_Impact_Explosion_FragGrenade_Concrete_08m = 2109,
  PFX_Impact_Explosion_ExplosiveArrow_Concrete_08m = 2110,
  PFX_Impact_Explosion_Landmine_Concrete_10m = 2111,
  PFX_Impact_Explosion_AirdropBomb_Concrete_10m = 2112,
  PFX_Impact_Explosion_FragGrenade_Wood_08m = 2118,
  PFX_Impact_Explosion_ExplosiveArrow_Wood_08m = 2119,
  PFX_Impact_Explosion_Landmine_Wood_10m = 2120,
  PFX_Impact_Explosion_AirdropBomb_Wood_10m = 2121,
  PFX_Impact_Explosion_FragGrenade_Grass_08m = 2136,
  PFX_Impact_Explosion_ExplosiveArrow_Grass_08m = 2137,
  PFX_Impact_Explosion_Landmine_Grass_10m = 2138,
  PFX_Impact_Explosion_AirdropBomb_Grass_10m = 2139,
  PFX_Impact_Explosion_FragGrenade_Rock_08m = 2145,
  PFX_Impact_Explosion_ExplosiveArrow_Rock_08m = 2146,
  PFX_Impact_Explosion_Landmine_Rock_10m = 2147,
  PFX_Impact_Explosion_AirdropBomb_Rock_10m = 2148,
  PFX_Impact_BulletLight_Rock = 3560,
  PFX_RallyPoint_Smoke_Orange = 3621,
  PFX_RallyPoint_Smoke_Green = 3622,
  PFX_RallyPoint_Smoke_Purple = 3623,
  PFX_RallyPoint_Smoke_Yellow = 3624,
  PFX_RallyPoint_Smoke_LimeGreen = 4537,
  PFX_RallyPoint_Smoke_Red = 4538,
  PFX_RallyPoint_Smoke_Blue = 4539,
  PFX_RallyPoint_Smoke_Teal = 4540,
  PFX_RallyPoint_Smoke_Magenta = 4541,
  PFX_Impact_BulletLight_Water = 3773,
  PFX_Impact_Explosion_FragGrenade_Water_08m = 4149,
  PFX_Impact_Explosion_ExplosiveArrow_Water_08m = 4150,
  PFX_Impact_Explosion_Landmine_Water_10m = 4151,
  PFX_Impact_Explosion_AirdropBomb_Water_10m = 4152,
  PFX_Impact_Mat_Metal_Vehicle_01m = 4707,
  PFX_Impact_Mat_Metal_Vehicle_03m = 4708,
  PFX_Impact_Mat_Metal_Vehicle_06m = 4709,
  PFX_Impact_Mat_Metal_Vehicle_09m = 4710,
  MAT_Explosion_FragGrenade_08m = 2301,
  MAT_Explosion_ExplosiveArrow_08m = 2302,
  MAT_Explosion_Landmine_10m = 2303,
  MAT_Explosion_AirdropBomb_10m = 2304,
  PFX_Impact_GrenadeSmoke_loop = 2333,
  PFX_Impact_GrenadeSmoke_loop_noSound = 2334,
  PFX_Impact_GrenadePoison_loop = 2335,
  PFX_Impact_GrenadePoison_loop_noSound = 2336,
  SFX_Run_Player = 2984,
  SFX_Run_Player_Dirt = 2980,
  SFX_Run_Player_Grass = 2981,
  SFX_Run_Player_Concrete = 2982,
  SFX_Run_Player_Metal = 2983,
  SFX_Run_Player_Water = 3633,
  SFX_Run_Player_WaterShallow = 3634,
  SFX_Run_Player_Ice = 3937,
  SFX_Run_Player_Metal_Grate = 4390,
  SFX_Walk_Player = 3625,
  SFX_Walk_Player_Dirt = 3626,
  SFX_Walk_Player_Grass = 3627,
  SFX_Walk_Player_Metal = 3628,
  SFX_Walk_Player_Concrete = 3629,
  SFX_Walk_Player_Water = 3630,
  SFX_Walk_Player_Snow = 3631,
  SFX_Walk_Player_WaterShallow = 3632,
  SFX_Walk_Player_Ice = 3938,
  SFX_Walk_Player_Metal_Grate = 4393,
  SFX_Jump_Player = 3635,
  SFX_Jump_Player_Dirt = 3636,
  SFX_Jump_Player_Grass = 3637,
  SFX_Jump_Player_Metal = 3638,
  SFX_Jump_Player_Concrete = 3639,
  SFX_Jump_Player_Water = 3640,
  SFX_Jump_Player_WaterShallow = 3641,
  SFX_Jump_Player_Metal_Grate = 4392,
  SFX_Land_Player = 3642,
  SFX_Land_Player_Dirt = 3643,
  SFX_Land_Player_Grass = 3644,
  SFX_Land_Player_Metal = 3645,
  SFX_Land_Player_Concrete = 3646,
  SFX_Land_Player_Water = 3647,
  SFX_Land_Player_WaterShallow = 3648,
  SFX_Land_Player_Metal_Grate = 4391,
  VEH_Engine_Boost_OffRoader = 5016,
  PFX_Compass_Needle = 5018,
  SFX_Walk_Player_Wood = 5020,
  SFX_Run_Player_Wood = 5021,
  SFX_Jump_Player_Wood = 5022,
  SFX_Land_Player_Wood = 5023,
  PFX_TreeFall_Start_Small = 5024,
  PFX_TreeFall_Land_CameraShake_Small = 5025,
  PFX_TreeFall_Start_Big = 5026,
  PFX_TreeFall_Land_CameraShake_Big = 5027,
  EFX_Fire_Furnace = 5028,
  PFX_Fishing_Bobbing_Trout = 5029,
  PFX_Fishing_Struggling_Trout = 5030,
  SFX_Idle_Player = 5032,
  SFX_Idle_Player_Water = 5033,
  PFX_Fire_Lighter = 5034,
  PFX_Scent_Human_Big = 5035,
  PFX_Scent_Human_Medium = 5036,
  PFX_Scent_Human_Small = 5037,
  PFX_Impact_AirDrop_Large = 5038,
  PFX_Impact_BulletShotgun_Default = 1300,
  PFX_Impact_BulletShotgun_Asphalt = 1301,
  PFX_Impact_BulletShotgun_Flesh = 1302,
  PFX_Impact_BulletShotgun_Concrete = 1304,
  PFX_Impact_BulletShotgun_Dirt = 1306,
  PFX_Impact_BulletShotgun_Glass = 1307,
  PFX_Impact_BulletShotgun_Grass = 1308,
  PFX_Impact_BulletShotgun_Metal = 1309,
  PFX_Impact_BulletShotgun_Rock = 1311,
  PFX_Impact_BulletShotgun_Rubber = 1313,
  PFX_Impact_BulletShotgun_Metal_Vehicle = 1314,
  PFX_Impact_BulletShotgun_Water = 1315,
  PFX_Impact_BulletShotgun_Wood = 1316,
  PFX_Impact_BulletShotgun_Zombie = 1317,
  PFX_Bleeding_Human_medium = 5041,
  MAT_Explosion_FlashGrenade = 4657,
  PFX_Impact_Explosion_FlashGrenade_Default = 4658,
  PFX_Impact_Explosion_FlashGrenade_Water = 4659,
  PFX_Bleeding_Human_moderate_loop = 5042,
  EFX_FireHydrant_Gushing = 5043,
  EFX_Fire_Barbecue = 5044,
  PFX_Light_Rigged_to_Battery = 5046,
  PFX_Circle_Bomb = 5047,
  SFX_Door_Wood_Open = 5048,
  SFX_Door_Wood_Close = 5049,
  PFX_Impact_Zombie_Flesh = 5050,
  EFX_Flare_Parachute_Rocket_Red = 5051,
  EFX_Water_Level_RainCatcher = 5052,
  EFX_Flare_ParachuteRocket = 5053,
  EFX_Light_SuperMarket_OutsideLight = 5054,
  EFX_Crop_Fertilizer = 5056,
  SFX_Player_Handcuff_Cuff = 5057,
  SFX_Player_Handcuff_Uncuff = 5058,
  SFX_Land_Player_Metal_Hollow = 5059,
  SFX_Land_Player_Barbed_Wire = 5060,
  SFX_Land_Player_Chain_Link = 5061,
  SFX_Jump_Player_Chain_Link = 5062,
  SFX_Run_Player_Chain_Link = 5063,
  SFX_Walk_Player_Chain_Link = 5064,
  SFX_Walk_Player_Barbed_Wire = 5065,
  SFX_Run_Player_Barbed_Wire = 5066,
  SFX_Jump_Player_Barbed_Wire = 5067,
  SFX_Jump_Player_Metal_Hollow = 5068,
  SFX_Run_Player_Metal_Hollow = 5069,
  SFX_Walk_Player_Metal_Hollow = 5070,
  SFX_PLAYER_RX_Breathing_Slow = 5071,
  SFX_PLAYER_RX_Breathing_Med = 5072,
  SFX_PLAYER_RX_Breathing_Fast = 5073,
  SFX_PLAYER_RX_Breathing_Exhausted = 5074,
  SFX_Door_Placeable_Metal_Open = 5075,
  SFX_Door_Placeable_Metal_Close = 5076,
  SFX_Door_Placeable_Wood_Shack_Open = 5077,
  SFX_Door_Placeable_Wood_Shack_Close = 5078,
  SFX_Door_Placeable_Wood_Shed_Open = 5079,
  SFX_Door_Placeable_Wood_Shed_Close = 5080,
  SFX_Gate_Placeable_Metal_Open = 5081,
  SFX_Gate_Placeable_Metal_Close = 5082,
  SFX_Door_Wood_Restaurant_Open = 5083,
  SFX_Door_Wood_Restaurant_Close = 5084,
  SFX_Door_Glass_Business_Open = 5085,
  SFX_Door_Glass_Business_Close = 5086,
  SFX_Door_Metal_Business_Open = 5087,
  SFX_Door_Metal_Business_Close = 5088,
  SFX_Door_Office_Open = 5089,
  SFX_Door_Office_Close = 5090,
  SFX_Door_Wood_Church_Open = 5091,
  SFX_Door_Wood_Church_Close = 5092,
  SFX_Door_Metal_Freezer_Open = 5093,
  SFX_Door_Metal_Freezer_Close = 5094,
  SFX_Door_Metal_Industrial_Open = 5095,
  SFX_Door_Metal_Industrial_Close = 5096,
  SFX_Leaderboard_Flip_Start = 5098,
  SFX_Leaderboard_Flip_Stop = 5099,
  PFX_Impact_BulletLight_Headshot_Human = 5100,
  PFX_Impact_BulletLight_Headshot_Zombie = 5101,
  VEH_Dust_OffRoader_Water = 5103,
  EFX_Waterfall_Dam = 5104,
  PFX_Bleeding_Human_severe_loop = 5105,
  PFX_Bleeding_Human_minor_loop = 5106,
  PFX_Bleeding_Zombie_minor_loop = 5108,
  PFX_Bleeding_Zombie_moderate_loop = 5109,
  PFX_Bleeding_Zombie_severe_loop = 5110,
  PFX_Impact_PunjiSticks_Blood = 5116,
  PFX_Impact_BulletHeavy_Water = 5118,
  VEH_Dust_OffRoader_Water_Idle = 5119,
  PFX_Impact_ArrowFlaming_Water = 5121,
  PFX_Impact_Fists_Default = 5122,
  SFX_Item_PickUp_BackPack = 5139,
  SFX_Item_PickUp_Ammo = 5140,
  SFX_Item_PickUp_Arrow = 5141,
  SFX_Item_PickUp_Arrows = 5142,
  SFX_Item_PickUp_Bat = 5143,
  SFX_Item_PickUp_Blade = 5144,
  SFX_Item_PickUp_Blunt_Weapon = 5145,
  SFX_Item_PickUp_Body_Armor = 5146,
  SFX_Item_PickUp_Can = 5147,
  SFX_Item_PickUp_Clothing = 5148,
  SFX_Item_PickUp_FirstAid = 5149,
  SFX_Item_PickUp_GasCan = 5150,
  SFX_Item_PickUp_Generic = 5151,
  SFX_Item_PickUp_Grenade = 5152,
  SFX_Item_PickUp_Helmet = 5153,
  SFX_Item_PickUp_Molotov = 5154,
  SFX_Item_PickUp_Package = 5155,
  SFX_Item_PickUp_Pistol = 5156,
  SFX_Item_PickUp_Rifle = 5157,
  SFX_Item_PickUp_WaterBottle = 5158,
  SFX_Item_PickUp_Milk_Jug = 5159,
  EFX_Insects_Cockroaches_01 = 5126,
  EFX_Insects_Maggots_01 = 5127,
  EFX_Insects_Termites_01 = 5128,
  EFX_Trash_Blowing_01 = 5129,
  EFX_Birds_Flying_01 = 5132,
  EFX_Birds_Flocking_01 = 5133,
  EFX_DandelionSeeds_01 = 5135,
  EFX_Insects_Butterflies_01 = 5160,
  EFX_Insects_Fireflies_01 = 5161,
  EFX_Insects_Flies_Swarm_01 = 5162,
  EFX_Insects_Gnats_01 = 5163,
  EFX_Insects_Mosquitos_01 = 5164,
  EFX_Insects_Moths_01 = 5165,
  PFX_Impact_Blade_Metal_Chainlink = 5166,
  PFX_Impact_Fists_Metal_Chainlink = 5167,
  PFX_Impact_Knife_Metal_Chainlink = 5168,
  PFX_Impact_BulletLight_Metal_Chainlink = 5169,
  PFX_Impact_Arrow_Metal_Chainlink = 5170,
  PFX_Seasonal_Halloween_Bats_ExplosionSkeleton = 5171,
  PFX_Seasonal_Halloween_Bats_SwarmSkeleton_loop = 5172,
  PFX_Damage_Fence_ChainLink_01 = 5173,
  PFX_Damage_Fence_ChainLink_02 = 5174,
  PFX_Damage_Fence_ChainLink_Industrial_01 = 5175,
  PFX_Damage_Fence_ChainLink_Industrial_Gate = 5176,
  EFX_FireHydrant_Dripping = 5178,
  SFX_Bomb_Falling = 5179,
  PFX_Impact_BulletHeavy_Dirt = 5180,
  PFX_Impact_BulletHeavy_Grass = 5181,
  PFX_Impact_BulletHeavy_Wood = 5182,
  PFX_Impact_BulletHeavy_Rock = 5183,
  PFX_Impact_BulletHeavy_Glass = 5185,
  PFX_Impact_BulletHeavy_Metal = 5187,
  PFX_Impact_BulletHeavy_Metal_Vehicle = 5189,
  PFX_Impact_BulletHeavy_Rubber = 5190,
  PFX_Poison_GasTrap_AOE_01 = 5191,
  PFX_Trap_Shock_Trigger = 5192,
  PFX_Impact_BulletHeavy_Asphalt = 5193,
  PFX_Impact_Blade_Asphalt = 5194,
  PFX_Char_Zombie_Screamer_Scream = 5203,
  VEH_DeadLoop_ATV = 5206,
  VEH_DeadLoop_OffRoader = 5207,
  VEH_DeadLoop_PickupTruck = 5208,
  VEH_DeadLoop_PoliceCar = 5209,
  PFX_Seasonal_Holiday_Snow_skel = 5211,
  PFX_Seasonal_Holiday_Snow_Explosion = 5214,
  PFX_Trap_Blinded_Trigger = 5215,
  TEST_TimeDilation = 5223,
  VEH_Damage_ATV_Stage04 = 5226,
  VEH_Damage_OffRoader_Stage04 = 5227,
  VEH_Damage_PickupTruck_Stage04 = 5228,
  VEH_Damage_PoliceCar_Stage04 = 5229,
  PFX_Impact_BulletLight_Textile = 5217,
  PFX_Impact_BulletHeavy_Textile = 5225,
  PFX_Impact_Blade_Textile = 5230,
  PFX_Impact_Fists_Textile = 5231,
  PFX_Impact_Fists_Asphalt = 5232,
  PFX_Impact_Arrow_Textile = 5236,
  PFX_Impact_Arrow_Asphalt = 5237,
  PFX_Char_Zombie_Screamer_Ambient = 5239,
  PFX_Char_Zombie_Exploder_Ambient = 5241,
  PFX_Char_Zombie_Exploder_Explosion = 5242,
  PFX_Char_Zombie_Gasser_ExplosionGasCloud = 5243,
  PFX_Char_Zombie_Gasser_Ambient = 5244,
  PFX_Char_Zombie_Screamer_Scream_Short = 5245,
  SFX_Player_Collar_Beep = 5247,
  EFX_Light_BusStop = 5246,
  EFX_Light_GasLamp = 5251,
  EFX_Light_Wall_Alley = 5252,
  PFX_Explosion_OilBarrel_04m = 5250,
  PFX_Meteor = 5253,
  TEST_UnlitSprites_Fog_Issues = 5255,
  SFX_Horn_Truck_Oneshot = 5256,
  EFX_Light_Wall_Alley_Damaged01 = 5257,
  EFX_Light_GasLamp_Damaged01_Flickering_Light = 5258,
  EFX_Light_GasLamp_Damaged02_Sporadic_Sparks = 5259,
  PFX_Weapon_Grenade_Screamer_Ambient = 5260,
  PFX_Damage_Light_GasLamp_Lit = 5261,
  PFX_Char_Zombie_Gasser_Explosion = 5262,
  PFX_Char_Zombie_Gasser_GasCloud = 5263,
  SFX_Player_Collar_Activate_Unsafe = 5264,
  SFX_Player_Collar_Deactivate_Safe = 5265,
  PFX_Char_Glasses_Goggles_Glow = 5266,
  PFX_Char_Glasses_Goggles_Glow_Female = 5267,
  PFX_Waypoint_Green = 5268,
  PFX_Events_GasCloud_WasteManagement_01 = 5269,
  SFX_Grenade_Screamer_Loop = 5270,
  EFX_Fire_OilBarrel = 5271,
  EFX_Fire_OilBarrel_Small = 5272,
  VEH_Helicopter_BladesLightsProjector = 5273,
  SFX_Proj_Bullet_By_Generic = 5275,
  SFX_Proj_Bullet_By_Sniper = 5276,
  VEH_Helicopter_ProjectorLights_Green = 5278,
  VEH_Helicopter_ProjectorLights_Red = 5279,
  PFX_Char_Zombie_Screamer_Ambient_ShortBurst = 5281,
  SFX_Proj_Arrow_By = 5282,
  SFX_Proj_Fire_Arrow_By = 5283,
  PFX_Damage_GraveStone_03 = 5287,
  PFX_Damage_GraveStone_02 = 5288,
  PFX_Damage_PatioChair_01 = 5289,
  PFX_MedicalMister_SurroundingMist = 5290,
  TEST_Bug_TimeScalar = 5291,
  EFX_TV = 5292,
  PFX_Damage_TV = 5293,
  PFX_Damage_Fence_Farm01 = 5294,
  PFX_Damage_Fence_Farm02 = 5295,
  PFX_Damage_Fence_ResidTall01 = 5296,
  PFX_Damage_Fence_ResidTallGate = 5297,
  PFX_Damage_Building_Interior_WallHole01 = 5298,
  PFX_Char_Death_Explosion_Body = 5299,
  PFX_Impact_Explosion_FragGrenade_Asphalt_08m = 5300,
  PFX_Impact_Explosion_FragGrenade_Default_08m = 5301,
  PFX_Impact_Explosion_Landmine_Asphalt_10m = 5303,
  PFX_Impact_Explosion_Landmine_Default_10m = 5304,
  PFX_Fire_Molotov_Impact = 5308,
  PFX_Fire_Molotov_Impact_Water = 5309,
  EFX_Light_Residential_Bedroom_LampLarge = 5310,
  EFX_Light_Residential_Bedroom_LampSmall = 5311,
  EFX_Stoplight_Flashing_All_wStreetlight = 5312,
  EFX_Stoplight_Flashing_All = 5313,
  EFX_Stoplight_Flashing_3_w_Streetlight = 5314,
  EFX_Stoplight_Flashing_2_w_Streetlight = 5315,
  VEH_Helicopter_BladesLights = 5319,
  PFX_Impact_Explosion_ExplosiveArrow_Asphalt_08m = 5320,
  PFX_Impact_Explosion_ExplosiveArrow_Default_08m = 5321,
  PFX_Trail_Projectile_Arrow_Explosive = 5322,
  PFX_Damage_Light_StreetLight_Flickering = 5323,
  PFX_Damage_Light_StreetLight_Sparks = 5324,
  TEST_LitParticles = 5327,
  PFX_Impact_Explosion_AirdropBomb_Default_10m = 5328,
  PFX_Impact_Explosion_AirdropBomb_Asphalt_10m = 5330,
  VEH_DeadLoop_ATV_Tire_LeftFront = 5334,
  VEH_DeadLoop_ATV_Tire_RightFront = 5335,
  VEH_DeadLoop_OffRoader_Tire_LeftFront = 5336,
  VEH_DeadLoop_OffRoader_Tire_Spare = 5337,
  VEH_DeadLoop_PickupTruck_Tire_LeftFront = 5338,
  VEH_DeadLoop_PickupTruck_Tire_RightRear = 5339,
  VEH_DeadLoop_PoliceCar_Tire_LeftFront = 5340,
  PFX_Impact_Arrow_Default = 5342,
  PFX_Impact_BulletHeavy_Default = 5343,
  PFX_Damage_Tree_City = 5329,
  VEH_Dust_OffRoader_Cardboard = 5344,
  VEH_Dust_ATV_Cardboard = 5346,
  EFX_Ceiling_Fan_01 = 5347,
  MAT_VehicleTreads_OffRoader = 5349,
  MAT_VehicleTreads_PickupTruck = 5350,
  MAT_VehicleTreads_PoliceCar = 5351,
  MAT_VehicleTreads_ATV = 5352,
  VEH_Treads_ATV_Dirt = 5353,
  VEH_Treads_OffRoader_Dirt = 5354,
  VEH_Treads_PickupTruck_Dirt = 5355,
  VEH_Treads_PoliceCar_Dirt = 5356,
  PFX_Trail_Projectile_Grenade = 5357,
  PFX_Trail_Projectile_Molotov = 5358,
  SFX_Veh_ATV_Cable_Release = 5359,
  EFX_Vent_Fan_Spinning = 5361,
  PFX_Impact_ArrowFlaming_Default = 5363,
  PFX_Char_Drink_WaterBottle_L = 5364,
  PFX_Char_Drink_WaterBottle_R = 5365,
  PFX_Impact_ArrowFlaming_Asphalt = 5367,
  PFX_Impact_ArrowFlaming_Metal_Chainlink = 5368,
  PFX_Impact_ArrowFlaming_Concrete = 5369,
  PFX_Impact_ArrowFlaming_Dirt = 5370,
  PFX_Impact_ArrowFlaming_Flesh = 5371,
  PFX_Impact_ArrowFlaming_Glass = 5372,
  PFX_Impact_ArrowFlaming_Grass = 5373,
  PFX_Impact_ArrowFlaming_Metal = 5374,
  PFX_Impact_ArrowFlaming_Rock = 5376,
  PFX_Impact_ArrowFlaming_Rubber = 5377,
  PFX_Impact_ArrowFlaming_Textile = 5378,
  PFX_Impact_ArrowFlaming_Metal_Vehicle = 5379,
  PFX_Impact_ArrowFlaming_Wood = 5380,
  PFX_Impact_ArrowFlaming_Zombie = 5381,
  TEST_StressTest = 5366,
  PFX_Char_Zombie_Spitter_AttackSpit_Projectile = 5382,
  PFX_Char_Zombie_Spitter_AttackSpit_Impact = 5384,
  PFX_Impact_Knife_Human_ForehandSlash = 5387,
  PFX_Impact_Knife_Human_ForwardStab = 5388,
  PFX_Impact_Knife_Zombie_ForwardStab = 5389,
  PFX_Impact_Knife_Zombie_ForehandSlash = 5390,
  PFX_Impact_Blunt_Human_Forehand = 5391,
  PFX_Impact_Blunt_Human_ForehandUppercut = 5392,
  PFX_Impact_Blunt_Zombie_Forehand = 5393,
  PFX_Impact_Blunt_Zombie_ForehandUppercut = 5394,
  PFX_Char_Zombie_Feeding_Hands = 5461,
  PFX_Char_Zombie_Feeding_HeadAndHands = 5465,
  PFX_Char_Zombie_Feeding_Head = 5468,
  SFX_WPN_Grenade_Land = 5495,
  PFX_Char_Zombie_Flinch_Up = 5496,
  PFX_Char_Zombie_Flinch_Down = 5497,
  PFX_Char_Zombie_Flinch_Left = 5498,
  PFX_Char_Zombie_Flinch_Right = 5499,
  PFX_Impact_Arrow_Carpet = 5395,
  PFX_Impact_Arrow_Metal_Barbedwire = 5396,
  PFX_Impact_Arrow_Metal_Grate = 5397,
  PFX_Impact_Arrow_Metal_Hard = 5398,
  PFX_Impact_Arrow_Metal_Hollow = 5399,
  PFX_Impact_ArrowFlaming_Carpet = 5400,
  PFX_Impact_ArrowFlaming_Metal_Barbedwire = 5401,
  PFX_Impact_ArrowFlaming_Metal_Grate = 5402,
  PFX_Impact_ArrowFlaming_Metal_Hard = 5403,
  PFX_Impact_ArrowFlaming_Metal_Hollow = 5404,
  PFX_Impact_BulletHeavy_Carpet = 5405,
  PFX_Impact_BulletHeavy_Concrete = 5406,
  PFX_Impact_BulletHeavy_Metal_Barbedwire = 5408,
  PFX_Impact_BulletHeavy_Metal_Chainlink = 5409,
  PFX_Impact_BulletHeavy_Metal_Grate = 5410,
  PFX_Impact_BulletHeavy_Metal_Hard = 5411,
  PFX_Impact_BulletHeavy_Metal_Hollow = 5412,
  PFX_Impact_BulletHeavy_Flesh = 5414,
  PFX_Impact_BulletHeavy_Zombie = 5415,
  PFX_Impact_BulletLight_Carpet = 5416,
  PFX_Impact_BulletLight_Metal_Barbedwire = 5417,
  PFX_Impact_BulletLight_Metal_Grate = 5418,
  PFX_Impact_BulletLight_Metal_Hard = 5419,
  PFX_Impact_BulletLight_Metal_Hollow = 5420,
  PFX_Impact_BulletShotgun_Carpet = 5421,
  PFX_Impact_BulletShotgun_Metal_Barbedwire = 5422,
  PFX_Impact_BulletShotgun_Metal_Chainlink = 5423,
  PFX_Impact_BulletShotgun_Metal_Grate = 5424,
  PFX_Impact_BulletShotgun_Metal_Hard = 5425,
  PFX_Impact_BulletShotgun_Metal_Hollow = 5426,
  PFX_Impact_Fists_Carpet = 5427,
  PFX_Impact_Fists_Metal_Barbedwire = 5428,
  PFX_Impact_Fists_Metal_Hard = 5429,
  PFX_Impact_Fists_Metal_Hollow = 5430,
  PFX_Impact_Guitar_Asphalt = 5431,
  PFX_Impact_Guitar_Carpet = 5432,
  PFX_Impact_Guitar_Metal_Chainlink = 5433,
  PFX_Impact_Guitar_Metal_Hard = 5434,
  PFX_Impact_Guitar_Metal_Hollow = 5435,
  PFX_Impact_Guitar_Metal_Barbedwire = 5436,
  PFX_Impact_Guitar_Textile = 5437,
  PFX_Impact_Guitar_Default = 5442,
  PFX_Impact_Blade_Carpet = 5443,
  PFX_Impact_Blade_Metal_Barbedwire = 5444,
  PFX_Impact_Blade_Metal_Hard = 5445,
  PFX_Impact_Blade_Metal_Hollow = 5446,
  PFX_Impact_Blade_Metal_Grate = 5447,
  PFX_Impact_Knife_Carpet = 5448,
  PFX_Impact_Knife_Metal_Barbedwire = 5449,
  PFX_Impact_Knife_Metal_Hard = 5450,
  PFX_Impact_Knife_Metal_Hollow = 5451,
  PFX_Impact_Knife_Textile = 5452,
  PFX_Impact_Torch_Carpet = 5453,
  PFX_Impact_Torch_Default = 5454,
  PFX_Impact_Torch_Metal_Hard = 5455,
  PFX_Impact_Torch_Metal_Hollow = 5456,
  PFX_Impact_Torch_Metal_Barbedwire = 5457,
  PFX_Impact_Torch_Metal_Grate = 5458,
  PFX_Impact_Torch_Metal_Chainlink = 5459,
  PFX_Impact_Blunt_Asphalt = 5460,
  PFX_Impact_Blunt_Concrete = 5462,
  PFX_Impact_Blunt_Carpet = 5463,
  PFX_Impact_Blunt_Dirt = 5464,
  PFX_Impact_Blunt_Flesh = 5467,
  PFX_Impact_Blunt_Zombie = 5469,
  PFX_Impact_Blunt_Metal = 5470,
  PFX_Impact_Blunt_Metal_Barbedwire = 5471,
  PFX_Impact_Blunt_Metal_Chainlink = 5472,
  PFX_Impact_Blunt_Metal_Grate = 5473,
  PFX_Impact_Blunt_Metal_Hard = 5474,
  PFX_Impact_Blunt_Metal_Hollow = 5475,
  PFX_Impact_Blunt_Metal_Vehicle = 5476,
  PFX_Impact_Blunt_Rock = 5477,
  PFX_Impact_Blunt_Textile = 5478,
  PFX_Impact_Blunt_Water = 5479,
  PFX_Impact_Blunt_Wood = 5480,
  PFX_Impact_Blunt_Default = 5481,
  PFX_Impact_Blade_Default = 5482,
  PFX_Impact_Knife_Metal_Grate = 5483,
  PFX_Impact_Fists_Metal_Grate = 5484,
  PFX_Impact_Guitar_Metal_Grate = 5485,
  PFX_Impact_BulletShotgun_Textile = 5486,
  PFX_Impact_Knife_Default = 5487,
  PFX_Impact_Knife_Asphalt = 5488,
  PFX_Impact_Blunt_Glass = 5489,
  PFX_Impact_Blunt_Grass = 5490,
  PFX_Impact_Torch_Asphalt = 5491,
  PFX_Impact_Torch_Textile = 5492,
  PFX_Impact_Fists_Water = 5493,
  MAT_Blunt = 5494,
  PFX_Damage_Light_StreetLightParking_Flickering = 5501,
  PFX_Damage_Light_StreetLightParking_Sparks = 5502,
  EFX_Light_StreetLightParking = 5504,
  PFX_Impact_Blunt_Zombie_Backhand = 5505,
  PFX_Impact_Blunt_Human_Backhand = 5506,
  MAT_Blunt_ForehandChop = 5508,
  MAT_Blunt_BackhandChop = 5509,
  MAT_Blunt_ForehandUppercut = 5510,
  MAT_Blunt_BackhandSlash = 5512,
  MAT_Blunt_ForehandSlash = 5513,
  MAT_Knife_ForehandSlash = 5514,
  MAT_Knife_ForehandChop = 5515,
  MAT_Knife_ForewardStab = 5516,
  EFX_Insects_Flies_Large_01 = 5517,
  EFX_Insects_Flies_Small_01 = 5518,
  EFX_Insects_Butterflies_Yellow_Small_01 = 5519,
  EFX_Insects_Flies_Small_02 = 5520,
  EFX_Props_Commercial_Props_FreshFoodWallCoolers = 5523,
  EFX_Props_Farm_Props_Crops_GreenPlantsRow_Row01 = 5524,
  EFX_Props_Farm_Props_Remains_Livestock01 = 5525,
  EFX_Props_Farm_Props_Remains_Livestock02 = 5526,
  EFX_Light_Commercial_Props_PendantLighting = 5527,
  EFX_Props_Light_Dam_Props_LightFlood = 5528,
  EFX_Props_Light_Dam_Props_LightLamp = 5529,
  EFX_Props_Light_Dam_Props_LightWall = 5530,
  EFX_Props_Light_FireStation_Structures_Buildings_FireHouse01_AddOnGarage01_Ext = 5531,
  EFX_Props_Light_FireStation_Structures_Buildings_FireHouse01_Ext = 5532,
  PFX_Trail_Projectile_DragonBreath = 5521,
  PFX_Mzl_DragonBreath = 5522,
  EFX_Props_Light_Dam_Props_LightEmergency = 5533,
  EFX_Insects_Flies_Tiny_01 = 5535,
  EFX_Waterfall_Dam_Z2 = 5538,
  EFX_Insects_Flies_Box = 5537,
  PFX_Char_Zombie_Spitter_Ambient = 5541,
  PFX_Char_Zombie_Spitter_Explosion = 5542,
  PFX_Char_Zombie_Spitter_ExplosionGasCloud = 5543,
  PFX_Char_Zombie_Spitter_GasCloud = 5544,
  PFX_Char_Zombie_Spitter_PowerUp = 5549,
  PFX_Seasonal_Fireworks_TripleBurst = 5551,
  EFX_Props_Light_City_Structures_Blockade_Floodlight01 = 5552,
  EFX_Props_Common_Props_RadioTower01 = 5553,
  EFX_Props_City_Props_Tree01 = 5554,
  SFX_VEH_Offroader_Horn = 5556,
  SFX_VEH_Pickup_Truck_Horn = 5557,
  SFX_VEH_Police_Car_Horn = 5558,
  SFX_VEH_ATV_Horn = 5559,
  EFX_Trash_Blowing_01_loop = 5560,
  SFX_VEH_ATV_Hotwire = 5561,
  SFX_VEH_OffRoader_Hotwire = 5562,
  SFX_VEH_Pickup_Truck_Hotwire = 5563,
  SFX_VEH_Police_Car_Hotwire = 5564,
  EFX_Props_Dam_WaterValve_Drip = 5555,
  EFX_Props_Dam_ControlWall = 5565,
  EFX_Props_Dam_DeskStation = 5566,
  EFX_Props_Light_Campground_Props_Lantern01 = 5568,
  TEST_WeaponFX_Fire = 5571,
  EFX_Props_Farm_Props_WeatherVane = 5572,
  EFX_Leaves_Falling_01_10m_loop = 5573,
  EFX_Leaves_Falling_01_30m_loop = 5574,
  EFX_Leaves_Falling_02_10m_loop = 5575,
  EFX_Leaves_Falling_02_30m_loop = 5576,
  PFX_Damage_Paper_Mail_CommunalMailbox = 5578,
  PFX_Damage_Paper_Mail_PostalBox = 5579,
  PFX_Damage_Paper_Newspapers_Vending = 5580,
  PFX_Damage_Paper_Trash_CityGarbageCan_01 = 5581,
  PFX_Damage_Paper_Trash_MunicipalGarbageCan = 5582,
  EFX_Props_Hospital_Fountain_Water = 5583,
  PFX_Damage_Paper_Trash_CityGarbageCan_02 = 5584,
  PFX_Damage_TrafficSigns_Highway = 5585,
  PFX_Damage_TrafficSigns_Highway_TwoPosts = 5586,
  PFX_Damage_TrafficSigns_StopSign = 5587,
  PFX_Damage_TrafficSigns_StreetSign = 5588,
  PFX_Damage_TrafficSigns_Town = 5589,
  PFX_Damage_TrafficSigns_Highway_TwoPosts_Persist = 5590,
  PFX_Damage_TrafficSigns_StopSign_Persist = 5591,
  PFX_Damage_TrafficSigns_Highway_Persist = 5592,
  PFX_Damage_TrafficSigns_Town_Persist = 5593,
  PFX_Damage_TrafficSigns_StreetSign_Persist = 5594,
  EFX_Birds_Swarming_01 = 5595,
  PFX_Damage_ParkingMeter = 5596,
  PFX_Damage_TrafficSigns_StreetSign_StreetName = 5597,
  PFX_Damage_TrafficSigns_Highway_Wood_TwoPosts = 5598,
  PFX_Damage_Tent_Campground = 5600,
  PFX_Damage_Light_Commercial_Props_PendantLighting = 5601,
  PFX_Damage_Fence_Farm01_Post = 5602,
  PFX_Damage_Cooler_Campground = 5603,
  PFX_Damage_Barrels_CabinBasket01 = 5604,
  PFX_Damage_TableAndChairs_Campground_FoldingChair = 5605,
  PFX_Damage_TableAndChairs_Church_FoldingChair = 5606,
  PFX_Damage_TableAndChairs_Residential_PatioChair = 5607,
  PFX_Damage_TableAndChairs_Residential_PatioTable = 5608,
  PFX_Damage_TableAndChairs_Restaurant_CafeChair = 5609,
  PFX_Damage_TableAndChairs_Restaurant_CafeTable = 5610,
  PFX_Damage_TableAndChairs_Restaurant_CafeUmbrella = 5611,
  PFX_Damage_TableAndChairs_Restaurant_SquareChair = 5612,
  PFX_Impact_Katana_Poison = 5613,
  PFX_Damage_Z1_Mailbox = 5614,
  PFX_Damage_Z1_BarbedWireFence1x1 = 5615,
  PFX_Damage_Z1_BarbedWireFence1x2 = 5616,
  PFX_Damage_Barriers_IndustrialCrowdBarrier = 5617,
  PFX_Damage_Z1_GarbageCan_02 = 5618,
  PFX_Damage_Crate_Industrial = 5619,
  PFX_Damage_Light_Bedroom_LampSmall = 5620,
  PFX_Damage_Light_Bedroom_LampTall = 5621,
  PFX_Damage_Light_City_BlockadeFloodlight = 5622,
  PFX_Damage_Light_Dam_EmergencyLight = 5623,
  PFX_Damage_Light_Dam_FloodLight = 5624,
  PFX_Damage_Light_Dam_LampLight = 5625,
  PFX_Damage_Light_Dam_WallLight = 5626,
  EFX_BoD_Helicopter_Blades = 5627,
  EFX_BoD_Helicopter_DustKickUp = 5628,
  PFX_Damage_ShoppingCart = 5629,
  PFX_Damage_RoadBlock_Gate_Military = 5630,
  EFX_CrateOpening_Fanfare_Blue = 5631,
  EFX_CrateOpening_Fanfare_Green = 5632,
  EFX_CrateOpening_Fanfare_Gold = 5633,
  EFX_CrateOpening_Fanfare_Purple = 5634,
  PFX_Damage_Fence_ChainLink_High1x1Corner = 5635,
  PFX_Damage_Fence_ChainLink_High1x1 = 5636,
  PFX_Damage_Fence_ChainLink_High1x2 = 5637,
  EFX_BoD_Fire_Plume_Huge_Line = 5638,
  EFX_BoD_Fire_Plume_Large = 5639,
  EFX_BoD_Fire_Plume_Medium = 5640,
  EFX_BoD_Steam_01 = 5641,
  EFX_BoD_Steam_02 = 5642,
  PFX_Damage_RoadBlock_WoodPost_Military = 5643,
  EFX_CrateOpening_CrateSpawn = 5644,
  EFX_Light_Hospital_CeilingLight = 5645,
  EFX_CrateOpening_Crate_Ambient = 5648,
  EFX_BoD_SnowGust_01 = 5649,
  SFX_AMB_Emit_Vending_Machine = 5650,
  EFX_BoD_C130_DustKickUp = 5651,
  EFX_BoD_C130_Blades = 5652,
  EFX_BoD_Snow_Blowing_Slow_01 = 5653,
  EFX_BoD_Grass_Blowing_Slow_01 = 5655,
  EFX_BoD_Blood_Splatter = 5656,
  EFX_BoD_RunwayLights = 5657,
  EFX_BoD_RunwayLights_Start = 5658,
  EFX_Windmiill_Spinning = 5659,
  PFX_Damage_Light_Campground_Lantern01 = 5660,
  EFX_CrateOpening_CrateDespawn = 5661,
  PFX_Damage_Fence_ChainLink_Industrial_Corner = 5662,
  PFX_Damage_Fence_ChainLink_Industrial_Breach = 5663,
  PFX_Damage_Fence_ChainLink_Industrial_Straight = 5664,
  PFX_Damage_Fence_ChainLink_Industrial_Post = 5665,
  PFX_CrateItem_Helmet_DemonMask_Green = 5668,
  PFX_CrateItem_Helmet_DemonMask_Orange = 5669
}

export enum HealTypes {
  OTHER = 1,
  BANDAGE = 2,
  MEDKIT = 3
}

export enum ItemTypes {
  WEAPON = 20,
  CONTAINER = 34
}

export enum AbilityIds {
  HEADLIGHTS_OFFROADER = 99998,

  MOTOR_OFFROADER = 1111153,

  TURBO_OFFROADER = 1111141,
  TURBO_PICKP_TRUCK = 1111292,
  TURBO_POLICE_CAR = 1111294,
  TURBO_ATV = 1111611,

  ABILITY_POLICE_CAR = 1111301,

  NV_GOGGLES = 1111272
}

export enum VehicleEffects {
  MOTOR_RUN_OFFROADER_1 = 90001,
  MOTOR_RUN_OFFROADER_2 = 100042,

  TURBO_PICKUP_TRUCK = 90068,
  TURBO_OFFROADER = 90000,
  TURBO_POLICE_CAR = 90069,
  TURBO_ATV = 90193
}

export enum MaterialTypes {
  DEFAULT = 0,
  METAL = 2,
  FLESH = 3,
  METAL_HARD = 4,
  WOOD = 5,
  GLASS = 6,
  GRASS = 7,
  CONCRETE = 10,
  ICE = 12,
  SNOW = 15,
  WATER = 17,
  VEHICLE_GROUND = 25,
  VEHICLE_AIR = 26,
  ASPHALT = 27,
  CERAMIC = 44,
  DIRTLIGHTBROWN = 45,
  DIRTDARKBROWN = 46,
  ROCKBROWN = 47,
  ROCKGREY = 48,
  SANDBROWN = 49,
  SANDRED = 50,
  WATERSHALLOW = 51,
  CHAINLINK = 52,
  RUBBER = 53,
  METAL_GRATE = 54,
  PLASTIC = 55,
  PLASTIC_SOFT = 56,
  CARPET = 57,
  ZOMBIE = 58,
  WOODBURNT = 59,
  CARDBOARD = 60,
  LEATHER = 61,
  KEVLAR = 62,
  METAL_HOLLOW = 63,
  CHAINLINK_FENCE = 64,
  BARBED_WIRE = 65,
  BULLET_PENETRATION_NO_FX = 66,
  WATER_PUDDLE = 67,
  DEFAULT_BULLET_PENETRATION = 69
}

export enum MeleeTypes {
  FISTS = 1,
  BLUNT = 2,
  BLADE = 3,
  KNIFE = 4,
  GUITAR = 5
}
